(function(exported) {
  if (typeof exports === 'object') {
    module.exports = exported;
  } else if (typeof define === 'function' && define.amd) {
    define(function() {
      return exported;
    });
  } else {
    
  }
})((function(require, undefined) { var global = this;

require.define('1', function(module, exports, __dirname, __filename, undefined){
var spipe = require('2', module);
var TokenStream = require('3', module);
var CalculatorTokenStream = TokenStream.extend({
        lib: {
            binDigit: /[01]/,
            octDigit: /{{binDigit}}|[2-7]/,
            decDigit: /{{octDigit}}|[89]/,
            hexDigit: /{{decDigit}}|[a-fA-F]/,
            exponent: /[eE][+-]?{{decDigit}}/,
            dot: /\./,
            space: /[ \t]+/,
            newline: /(?:\r\n|\r|\n)+/,
            base2int: /0[bB]{{binDigit}}+/,
            base8int: /0[oO]{{octDigit}}+/,
            base10int: /{{decDigit}}+{{exponent}}?/,
            base16int: /0[xX]{{hexDigit}}+/,
            dotFloat: /{{dot}}{{decDigit}}+{{exponent}}?/,
            normalFloat: /{{decDigit}}+{{dotFloat}}?/,
            float: /{{dotFloat}}|{{normalFloat}}|{{base10int}}/,
            boolean: /true|false/,
            name: /^[_$a-zA-Z\xa0-\uffff][_$a-zA-Z0-9\xa0-\uffff]*$/,
            operator: /<=|>=|[=<>+.\-*\/%&|^]/,
            stringStart: /"/
        },
        states: {
            start: [
                'space',
                'newline',
                'base2int',
                'base8int',
                'base16int',
                'float',
                'boolean',
                'name',
                'operator',
                'stringStart'
            ]
        },
        factory: {
            space: function () {
            },
            newline: function () {
            }
        }
    });
function tokenize() {
    return new CalculatorTokenStream(this);
}
runMocha({
    'TokenStream': {
        'tokenize synchronously': function () {
            deepEqual(spipe('5.5   0xff  true+10')(tokenize)(), [
                '5.5',
                '0xff',
                'true',
                '+',
                '10'
            ]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = spipe('5.5   0xff  true+10')(tokenize)(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    '5.5',
                    '0xff',
                    'true',
                    '+',
                    '10'
                ]);
                done();
            });
        }
    }
});
});
require.define('3', function(module, exports, __dirname, __filename, undefined){
var has = require('4', module);
var is = require('5', module);
var classic = require('6', module);
var PullStream = require('7', module);
function compileRule(rule, lib, cache) {
    if (has(cache, rule))
        return cache[rule];
    if (has(rule, 'source')) {
        rule = rule.source;
    }
    rule = rule.toString();
    var compiled = rule.replace(/\((?!\?\:)(.+)\)/, '(?:$1)');
    compiled = compiled.replace(/{{(\w+)}}/g, function (match, r) {
        var resolved = lib[r];
        if (!resolved)
            throw new Error('Cant resolve lexer rule \'' + r + '\'');
        return '(?:' + compileRule(resolved, lib, cache) + ')';
    });
    return cache[rule] = compiled;
}
function compile(grammar) {
    var rv = {};
    var cache = {};
    var states = grammar.states;
    for (var k in states) {
        if (!has(states, k))
            continue;
        var alts = states[k];
        var components = [];
        for (var i = 0, l = alts.length; i < l; i++) {
            components.push('(' + compileRule('{{' + alts[i] + '}}', grammar.lib, cache) + ')');
        }
        rv[k] = {
            rules: alts,
            regexp: new RegExp('^(?:' + components.join('|') + ')')
        };
    }
    return rv;
}
var TokenStream = PullStream.extend({
        constructor: function TokenStream(source, grammars, factory) {
            PullStream.call(this, source);
            this._lexState = {
                stack: [grammars.start],
                grammars: grammars,
                factory: factory,
                startPos: 0,
                pos: 0,
                lineStart: 1,
                colStart: 0,
                line: 1,
                col: 0,
                buffered: '',
                text: null
            };
        },
        _currentState: function () {
            var stack = this._lexState.stack;
            return stack[stack.length - 1];
        },
        _seek: function (count) {
            var state = this._lexState, raw, lines;
            state.lineStart = state.line;
            state.colStart = state.col;
            state.startPos = state.pos;
            state.pos += count;
            raw = state.buffered.slice(state.startPos, state.pos);
            state.buffered = state.buffered.slice(count);
            lines = raw.split('\n').length - 1;
            if (lines) {
                state.line += lines;
                state.col = /\n(.*)$/.exec(raw)[1].length;
            } else {
                state.col += raw.length;
            }
        },
        _process: function (chunk) {
            var state = this._lexState;
            var factory = state.factory;
            state.buffered += chunk;
            while (state.buffered.length) {
                var match;
                var currentState = this._currentState();
                var rules = currentState.rules;
                var regexp = currentState.regexp;
                if (!(match = regexp.exec(state.buffered)))
                    break;
                this._seek(match[0].length);
                for (var i = 0, l = rules.length; i < l; i++) {
                    var matchIdx = i + 1;
                    var rule = rules[i];
                    if (match[matchIdx]) {
                        state.text = match[matchIdx];
                        if (has(factory, rule)) {
                            var result = factory[rule](state);
                            if (!is.nil(result))
                                this.push(result);
                        } else {
                            this.push(state.text);
                        }
                        break;
                    }
                }
            }
        }
    });
TokenStream.extend = function (grammar) {
    var factory = grammar.factory || {};
    grammar = compile(grammar);
    return classic({
        constructor: function (source) {
            TokenStream.call(this, source, grammar, factory);
        }
    }, TokenStream);
};
module.exports = TokenStream;
});
require.define('7', function(module, exports, __dirname, __filename, undefined){
var PassThrough = require('8', module).PassThrough;
var classic = require('6', module);
var AnythingStream = require('9', module);
function PullState(source) {
    this.source = source;
    this.started = false;
    this.ended = false;
    this.endEmitted = false;
}
var PullStream = AnythingStream.extend({
        constructor: function PullStream(source) {
            AnythingStream.call(this);
            this._pullState = new PullState(source || new PassThrough());
        },
        _write: function (chunk, encoding, callback) {
            this._pullState.source._write(chunk, encoding, callback);
        },
        _read: function () {
            var _this = this, state = this._pullState;
            if (state.started)
                return;
            state.started = true;
            state.ended = false;
            this.on('pause', function () {
                state.source.pause();
            });
            this.on('resume', function () {
                state.source.resume();
            });
            state.source.on('close', function () {
                _this.emit('close');
            });
            state.source.on('error', function (err) {
                _this.emit('error', err);
            });
            state.source.on('end', function () {
                _this._end();
            });
            state.source.on('data', function (chunk) {
                _this._process(chunk);
            });
        },
        _done: function () {
            var state = this._pullState;
            return state.ended || (state.ended = state.source._done ? state.source._done() : false);
        },
        setEncoding: function (encoding) {
            return this._pullState.source.setEncoding(encoding);
        },
        close: function () {
            var state = this._pullState;
            this.pause();
            if (typeof state.source.close === 'function')
                state.source.close();
            state.ended = true;
        },
        destroy: function () {
            var state = this._pullState;
            this.pause();
            if (typeof state.source.destroy === 'function')
                state.source.destroy();
            state.ended = true;
        }
    });
module.exports = PullStream;
});
require.define('9', function(module, exports, __dirname, __filename, undefined){
var Duplex = require('8', module).Duplex;
var classic = require('6', module);
var is = require('5', module);
var AnythingStream = classic({
        constructor: function AnythingStream() {
            Duplex.call(this, { objectMode: true });
        },
        push: function (chunk) {
            var state = this._readableState;
            state.length += 1;
            state.buffer.push(chunk);
            state.reading = false;
            if (this._done())
                this._end();
        },
        _forward: function (chunk) {
            this.emit('data', chunk);
            if (this._done())
                this._end();
        },
        _end: function () {
            if (is.func(this._ended))
                this._ended();
            Duplex.prototype.push.call(this, null);
        },
        _done: function () {
            throw new Error('not implemented');
        }
    }, Duplex);
module.exports = AnythingStream;
});
require.define('6', function(module, exports, __dirname, __filename, undefined){
var inherits = require('10', module);
var has = require('4', module);
module.exports = function classic(protoSetup, superClass) {
    var constructor, protoTmp;
    if (typeof protoSetup === 'function') {
        protoTmp = {};
        protoSetup.call(protoTmp);
    } else {
        protoTmp = protoSetup;
    }
    constructor = protoTmp.constructor;
    if (!has(protoTmp, 'constructor')) {
        if (superClass) {
            constructor = function () {
                superClass.apply(this, arguments);
            };
        } else {
            constructor = function () {
            };
        }
    }
    delete protoTmp.constructor;
    if (superClass) {
        inherits(constructor, superClass);
    }
    for (var k in protoTmp) {
        if (!has(protoTmp, k))
            continue;
        constructor.prototype[k] = protoTmp[k];
    }
    constructor.extend = function (protoSetup) {
        return classic(protoSetup, constructor);
    };
    return constructor;
};
});
require.define('4', function(module, exports, __dirname, __filename, undefined){
var hasOwn = Object.prototype.hasOwnProperty;
module.exports = function has(obj, property) {
    return hasOwn.call(obj, property);
};
});
require.define('10', function(module, exports, __dirname, __filename, undefined){
if (typeof Object.create === 'function') {
    module.exports = function inherits(ctor, superCtor) {
        ctor.super_ = superCtor;
        ctor.prototype = Object.create(superCtor.prototype, {
            constructor: {
                value: ctor,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
    };
} else {
    module.exports = function inherits(ctor, superCtor) {
        ctor.super_ = superCtor;
        var TempCtor = function () {
        };
        TempCtor.prototype = superCtor.prototype;
        ctor.prototype = new TempCtor();
        ctor.prototype.constructor = ctor;
    };
}
});
require.define('8', function(module, exports, __dirname, __filename, undefined){
module.exports = Stream;
var EE = require('11', module).EventEmitter;
var util = require('12', module);
util.inherits(Stream, EE);
Stream.Readable = require('13', module);
Stream.Writable = require('14', module);
Stream.Duplex = require('15', module);
Stream.Transform = require('16', module);
Stream.PassThrough = require('17', module);
Stream.Stream = Stream;
function Stream() {
    EE.call(this);
}
Stream.prototype.pipe = function (dest, options) {
    var source = this;
    function ondata(chunk) {
        if (dest.writable) {
            if (false === dest.write(chunk) && source.pause) {
                source.pause();
            }
        }
    }
    source.on('data', ondata);
    function ondrain() {
        if (source.readable && source.resume) {
            source.resume();
        }
    }
    dest.on('drain', ondrain);
    if (!dest._isStdio && (!options || options.end !== false)) {
        source.on('end', onend);
        source.on('close', onclose);
    }
    var didOnEnd = false;
    function onend() {
        if (didOnEnd)
            return;
        didOnEnd = true;
        dest.end();
    }
    function onclose() {
        if (didOnEnd)
            return;
        didOnEnd = true;
        if (typeof dest.destroy === 'function')
            dest.destroy();
    }
    function onerror(er) {
        cleanup();
        if (EE.listenerCount(this, 'error') === 0) {
            throw er;
        }
    }
    source.on('error', onerror);
    dest.on('error', onerror);
    function cleanup() {
        source.removeListener('data', ondata);
        dest.removeListener('drain', ondrain);
        source.removeListener('end', onend);
        source.removeListener('close', onclose);
        source.removeListener('error', onerror);
        dest.removeListener('error', onerror);
        source.removeListener('end', cleanup);
        source.removeListener('close', cleanup);
        dest.removeListener('close', cleanup);
    }
    source.on('end', cleanup);
    source.on('close', cleanup);
    dest.on('close', cleanup);
    dest.emit('pipe', source);
    return dest;
};
});
require.define('17', function(module, exports, __dirname, __filename, undefined){
module.exports = PassThrough;
var Transform = require('16', module);
var util = require('12', module);
util.inherits(PassThrough, Transform);
function PassThrough(options) {
    if (!(this instanceof PassThrough))
        return new PassThrough(options);
    Transform.call(this, options);
}
PassThrough.prototype._transform = function (chunk, encoding, cb) {
    cb(null, chunk);
};
});
require.define('12', function(module, exports, __dirname, __filename, undefined){
var shims = require('18', module);
var formatRegExp = /%[sdj%]/g;
exports.format = function (f) {
    if (!isString(f)) {
        var objects = [];
        for (var i = 0; i < arguments.length; i++) {
            objects.push(inspect(arguments[i]));
        }
        return objects.join(' ');
    }
    var i = 1;
    var args = arguments;
    var len = args.length;
    var str = String(f).replace(formatRegExp, function (x) {
            if (x === '%%')
                return '%';
            if (i >= len)
                return x;
            switch (x) {
            case '%s':
                return String(args[i++]);
            case '%d':
                return Number(args[i++]);
            case '%j':
                try {
                    return JSON.stringify(args[i++]);
                } catch (_) {
                    return '[Circular]';
                }
            default:
                return x;
            }
        });
    for (var x = args[i]; i < len; x = args[++i]) {
        if (isNull(x) || !isObject(x)) {
            str += ' ' + x;
        } else {
            str += ' ' + inspect(x);
        }
    }
    return str;
};
function inspect(obj, opts) {
    var ctx = {
            seen: [],
            stylize: stylizeNoColor
        };
    if (arguments.length >= 3)
        ctx.depth = arguments[2];
    if (arguments.length >= 4)
        ctx.colors = arguments[3];
    if (isBoolean(opts)) {
        ctx.showHidden = opts;
    } else if (opts) {
        exports._extend(ctx, opts);
    }
    if (isUndefined(ctx.showHidden))
        ctx.showHidden = false;
    if (isUndefined(ctx.depth))
        ctx.depth = 2;
    if (isUndefined(ctx.colors))
        ctx.colors = false;
    if (isUndefined(ctx.customInspect))
        ctx.customInspect = true;
    if (ctx.colors)
        ctx.stylize = stylizeWithColor;
    return formatValue(ctx, obj, ctx.depth);
}
exports.inspect = inspect;
inspect.colors = {
    'bold': [
        1,
        22
    ],
    'italic': [
        3,
        23
    ],
    'underline': [
        4,
        24
    ],
    'inverse': [
        7,
        27
    ],
    'white': [
        37,
        39
    ],
    'grey': [
        90,
        39
    ],
    'black': [
        30,
        39
    ],
    'blue': [
        34,
        39
    ],
    'cyan': [
        36,
        39
    ],
    'green': [
        32,
        39
    ],
    'magenta': [
        35,
        39
    ],
    'red': [
        31,
        39
    ],
    'yellow': [
        33,
        39
    ]
};
inspect.styles = {
    'special': 'cyan',
    'number': 'yellow',
    'boolean': 'yellow',
    'undefined': 'grey',
    'null': 'bold',
    'string': 'green',
    'date': 'magenta',
    'regexp': 'red'
};
function stylizeWithColor(str, styleType) {
    var style = inspect.styles[styleType];
    if (style) {
        return '\x1b[' + inspect.colors[style][0] + 'm' + str + '\x1b[' + inspect.colors[style][1] + 'm';
    } else {
        return str;
    }
}
function stylizeNoColor(str, styleType) {
    return str;
}
function arrayToHash(array) {
    var hash = {};
    shims.forEach(array, function (val, idx) {
        hash[val] = true;
    });
    return hash;
}
function formatValue(ctx, value, recurseTimes) {
    if (ctx.customInspect && value && isFunction(value.inspect) && value.inspect !== exports.inspect && !(value.constructor && value.constructor.prototype === value)) {
        var ret = value.inspect(recurseTimes);
        if (!isString(ret)) {
            ret = formatValue(ctx, ret, recurseTimes);
        }
        return ret;
    }
    var primitive = formatPrimitive(ctx, value);
    if (primitive) {
        return primitive;
    }
    var keys = shims.keys(value);
    var visibleKeys = arrayToHash(keys);
    if (ctx.showHidden) {
        keys = shims.getOwnPropertyNames(value);
    }
    if (keys.length === 0) {
        if (isFunction(value)) {
            var name = value.name ? ': ' + value.name : '';
            return ctx.stylize('[Function' + name + ']', 'special');
        }
        if (isRegExp(value)) {
            return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
        }
        if (isDate(value)) {
            return ctx.stylize(Date.prototype.toString.call(value), 'date');
        }
        if (isError(value)) {
            return formatError(value);
        }
    }
    var base = '', array = false, braces = [
            '{',
            '}'
        ];
    if (isArray(value)) {
        array = true;
        braces = [
            '[',
            ']'
        ];
    }
    if (isFunction(value)) {
        var n = value.name ? ': ' + value.name : '';
        base = ' [Function' + n + ']';
    }
    if (isRegExp(value)) {
        base = ' ' + RegExp.prototype.toString.call(value);
    }
    if (isDate(value)) {
        base = ' ' + Date.prototype.toUTCString.call(value);
    }
    if (isError(value)) {
        base = ' ' + formatError(value);
    }
    if (keys.length === 0 && (!array || value.length == 0)) {
        return braces[0] + base + braces[1];
    }
    if (recurseTimes < 0) {
        if (isRegExp(value)) {
            return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
        } else {
            return ctx.stylize('[Object]', 'special');
        }
    }
    ctx.seen.push(value);
    var output;
    if (array) {
        output = formatArray(ctx, value, recurseTimes, visibleKeys, keys);
    } else {
        output = keys.map(function (key) {
            return formatProperty(ctx, value, recurseTimes, visibleKeys, key, array);
        });
    }
    ctx.seen.pop();
    return reduceToSingleString(output, base, braces);
}
function formatPrimitive(ctx, value) {
    if (isUndefined(value))
        return ctx.stylize('undefined', 'undefined');
    if (isString(value)) {
        var simple = '\'' + JSON.stringify(value).replace(/^"|"$/g, '').replace(/'/g, '\\\'').replace(/\\"/g, '"') + '\'';
        return ctx.stylize(simple, 'string');
    }
    if (isNumber(value))
        return ctx.stylize('' + value, 'number');
    if (isBoolean(value))
        return ctx.stylize('' + value, 'boolean');
    if (isNull(value))
        return ctx.stylize('null', 'null');
}
function formatError(value) {
    return '[' + Error.prototype.toString.call(value) + ']';
}
function formatArray(ctx, value, recurseTimes, visibleKeys, keys) {
    var output = [];
    for (var i = 0, l = value.length; i < l; ++i) {
        if (hasOwnProperty(value, String(i))) {
            output.push(formatProperty(ctx, value, recurseTimes, visibleKeys, String(i), true));
        } else {
            output.push('');
        }
    }
    shims.forEach(keys, function (key) {
        if (!key.match(/^\d+$/)) {
            output.push(formatProperty(ctx, value, recurseTimes, visibleKeys, key, true));
        }
    });
    return output;
}
function formatProperty(ctx, value, recurseTimes, visibleKeys, key, array) {
    var name, str, desc;
    desc = shims.getOwnPropertyDescriptor(value, key) || { value: value[key] };
    if (desc.get) {
        if (desc.set) {
            str = ctx.stylize('[Getter/Setter]', 'special');
        } else {
            str = ctx.stylize('[Getter]', 'special');
        }
    } else {
        if (desc.set) {
            str = ctx.stylize('[Setter]', 'special');
        }
    }
    if (!hasOwnProperty(visibleKeys, key)) {
        name = '[' + key + ']';
    }
    if (!str) {
        if (shims.indexOf(ctx.seen, desc.value) < 0) {
            if (isNull(recurseTimes)) {
                str = formatValue(ctx, desc.value, null);
            } else {
                str = formatValue(ctx, desc.value, recurseTimes - 1);
            }
            if (str.indexOf('\n') > -1) {
                if (array) {
                    str = str.split('\n').map(function (line) {
                        return '  ' + line;
                    }).join('\n').substr(2);
                } else {
                    str = '\n' + str.split('\n').map(function (line) {
                        return '   ' + line;
                    }).join('\n');
                }
            }
        } else {
            str = ctx.stylize('[Circular]', 'special');
        }
    }
    if (isUndefined(name)) {
        if (array && key.match(/^\d+$/)) {
            return str;
        }
        name = JSON.stringify('' + key);
        if (name.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)) {
            name = name.substr(1, name.length - 2);
            name = ctx.stylize(name, 'name');
        } else {
            name = name.replace(/'/g, '\\\'').replace(/\\"/g, '"').replace(/(^"|"$)/g, '\'');
            name = ctx.stylize(name, 'string');
        }
    }
    return name + ': ' + str;
}
function reduceToSingleString(output, base, braces) {
    var numLinesEst = 0;
    var length = shims.reduce(output, function (prev, cur) {
            numLinesEst++;
            if (cur.indexOf('\n') >= 0)
                numLinesEst++;
            return prev + cur.replace(/\u001b\[\d\d?m/g, '').length + 1;
        }, 0);
    if (length > 60) {
        return braces[0] + (base === '' ? '' : base + '\n ') + ' ' + output.join(',\n  ') + ' ' + braces[1];
    }
    return braces[0] + base + ' ' + output.join(', ') + ' ' + braces[1];
}
function isArray(ar) {
    return shims.isArray(ar);
}
exports.isArray = isArray;
function isBoolean(arg) {
    return typeof arg === 'boolean';
}
exports.isBoolean = isBoolean;
function isNull(arg) {
    return arg === null;
}
exports.isNull = isNull;
function isNullOrUndefined(arg) {
    return arg == null;
}
exports.isNullOrUndefined = isNullOrUndefined;
function isNumber(arg) {
    return typeof arg === 'number';
}
exports.isNumber = isNumber;
function isString(arg) {
    return typeof arg === 'string';
}
exports.isString = isString;
function isSymbol(arg) {
    return typeof arg === 'symbol';
}
exports.isSymbol = isSymbol;
function isUndefined(arg) {
    return arg === void 0;
}
exports.isUndefined = isUndefined;
function isRegExp(re) {
    return isObject(re) && objectToString(re) === '[object RegExp]';
}
exports.isRegExp = isRegExp;
function isObject(arg) {
    return typeof arg === 'object' && arg;
}
exports.isObject = isObject;
function isDate(d) {
    return isObject(d) && objectToString(d) === '[object Date]';
}
exports.isDate = isDate;
function isError(e) {
    return isObject(e) && objectToString(e) === '[object Error]';
}
exports.isError = isError;
function isFunction(arg) {
    return typeof arg === 'function';
}
exports.isFunction = isFunction;
function isPrimitive(arg) {
    return arg === null || typeof arg === 'boolean' || typeof arg === 'number' || typeof arg === 'string' || typeof arg === 'symbol' || typeof arg === 'undefined';
}
exports.isPrimitive = isPrimitive;
function isBuffer(arg) {
    return arg && typeof arg === 'object' && typeof arg.copy === 'function' && typeof arg.fill === 'function' && typeof arg.binarySlice === 'function';
    ;
}
exports.isBuffer = isBuffer;
function objectToString(o) {
    return Object.prototype.toString.call(o);
}
function pad(n) {
    return n < 10 ? '0' + n.toString(10) : n.toString(10);
}
var months = [
        'Jan',
        'Feb',
        'Mar',
        'Apr',
        'May',
        'Jun',
        'Jul',
        'Aug',
        'Sep',
        'Oct',
        'Nov',
        'Dec'
    ];
function timestamp() {
    var d = new Date();
    var time = [
            pad(d.getHours()),
            pad(d.getMinutes()),
            pad(d.getSeconds())
        ].join(':');
    return [
        d.getDate(),
        months[d.getMonth()],
        time
    ].join(' ');
}
exports.log = function () {
    console.log('%s - %s', timestamp(), exports.format.apply(exports, arguments));
};
exports.inherits = function (ctor, superCtor) {
    ctor.super_ = superCtor;
    ctor.prototype = shims.create(superCtor.prototype, {
        constructor: {
            value: ctor,
            enumerable: false,
            writable: true,
            configurable: true
        }
    });
};
exports._extend = function (origin, add) {
    if (!add || !isObject(add))
        return origin;
    var keys = shims.keys(add);
    var i = keys.length;
    while (i--) {
        origin[keys[i]] = add[keys[i]];
    }
    return origin;
};
function hasOwnProperty(obj, prop) {
    return Object.prototype.hasOwnProperty.call(obj, prop);
}
});
require.define('18', function(module, exports, __dirname, __filename, undefined){
var toString = Object.prototype.toString;
var hasOwnProperty = Object.prototype.hasOwnProperty;
function isArray(xs) {
    return toString.call(xs) === '[object Array]';
}
exports.isArray = typeof Array.isArray === 'function' ? Array.isArray : isArray;
exports.indexOf = function indexOf(xs, x) {
    if (xs.indexOf)
        return xs.indexOf(x);
    for (var i = 0; i < xs.length; i++) {
        if (x === xs[i])
            return i;
    }
    return -1;
};
exports.filter = function filter(xs, fn) {
    if (xs.filter)
        return xs.filter(fn);
    var res = [];
    for (var i = 0; i < xs.length; i++) {
        if (fn(xs[i], i, xs))
            res.push(xs[i]);
    }
    return res;
};
exports.forEach = function forEach(xs, fn, self) {
    if (xs.forEach)
        return xs.forEach(fn, self);
    for (var i = 0; i < xs.length; i++) {
        fn.call(self, xs[i], i, xs);
    }
};
exports.map = function map(xs, fn) {
    if (xs.map)
        return xs.map(fn);
    var out = new Array(xs.length);
    for (var i = 0; i < xs.length; i++) {
        out[i] = fn(xs[i], i, xs);
    }
    return out;
};
exports.reduce = function reduce(array, callback, opt_initialValue) {
    if (array.reduce)
        return array.reduce(callback, opt_initialValue);
    var value, isValueSet = false;
    if (2 < arguments.length) {
        value = opt_initialValue;
        isValueSet = true;
    }
    for (var i = 0, l = array.length; l > i; ++i) {
        if (array.hasOwnProperty(i)) {
            if (isValueSet) {
                value = callback(value, array[i], i, array);
            } else {
                value = array[i];
                isValueSet = true;
            }
        }
    }
    return value;
};
if ('ab'.substr(-1) !== 'b') {
    exports.substr = function (str, start, length) {
        if (start < 0)
            start = str.length + start;
        return str.substr(start, length);
    };
} else {
    exports.substr = function (str, start, length) {
        return str.substr(start, length);
    };
}
exports.trim = function (str) {
    if (str.trim)
        return str.trim();
    return str.replace(/^\s+|\s+$/g, '');
};
exports.bind = function () {
    var args = Array.prototype.slice.call(arguments);
    var fn = args.shift();
    if (fn.bind)
        return fn.bind.apply(fn, args);
    var self = args.shift();
    return function () {
        fn.apply(self, args.concat([Array.prototype.slice.call(arguments)]));
    };
};
function create(prototype, properties) {
    var object;
    if (prototype === null) {
        object = { '__proto__': null };
    } else {
        if (typeof prototype !== 'object') {
            throw new TypeError('typeof prototype[' + typeof prototype + '] != \'object\'');
        }
        var Type = function () {
        };
        Type.prototype = prototype;
        object = new Type();
        object.__proto__ = prototype;
    }
    if (typeof properties !== 'undefined' && Object.defineProperties) {
        Object.defineProperties(object, properties);
    }
    return object;
}
exports.create = typeof Object.create === 'function' ? Object.create : create;
function notObject(object) {
    return typeof object != 'object' && typeof object != 'function' || object === null;
}
function keysShim(object) {
    if (notObject(object)) {
        throw new TypeError('Object.keys called on a non-object');
    }
    var result = [];
    for (var name in object) {
        if (hasOwnProperty.call(object, name)) {
            result.push(name);
        }
    }
    return result;
}
function propertyShim(object) {
    if (notObject(object)) {
        throw new TypeError('Object.getOwnPropertyNames called on a non-object');
    }
    var result = keysShim(object);
    if (exports.isArray(object) && exports.indexOf(object, 'length') === -1) {
        result.push('length');
    }
    return result;
}
var keys = typeof Object.keys === 'function' ? Object.keys : keysShim;
var getOwnPropertyNames = typeof Object.getOwnPropertyNames === 'function' ? Object.getOwnPropertyNames : propertyShim;
if (new Error().hasOwnProperty('description')) {
    var ERROR_PROPERTY_FILTER = function (obj, array) {
        if (toString.call(obj) === '[object Error]') {
            array = exports.filter(array, function (name) {
                return name !== 'description' && name !== 'number' && name !== 'message';
            });
        }
        return array;
    };
    exports.keys = function (object) {
        return ERROR_PROPERTY_FILTER(object, keys(object));
    };
    exports.getOwnPropertyNames = function (object) {
        return ERROR_PROPERTY_FILTER(object, getOwnPropertyNames(object));
    };
} else {
    exports.keys = keys;
    exports.getOwnPropertyNames = getOwnPropertyNames;
}
function valueObject(value, key) {
    return { value: value[key] };
}
if (typeof Object.getOwnPropertyDescriptor === 'function') {
    try {
        Object.getOwnPropertyDescriptor({ 'a': 1 }, 'a');
        exports.getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;
    } catch (e) {
        exports.getOwnPropertyDescriptor = function (value, key) {
            try {
                return Object.getOwnPropertyDescriptor(value, key);
            } catch (e) {
                return valueObject(value, key);
            }
        };
    }
} else {
    exports.getOwnPropertyDescriptor = valueObject;
}
});
require.define('16', function(module, exports, __dirname, __filename, undefined){
module.exports = Transform;
var Duplex = require('15', module);
var util = require('12', module);
util.inherits(Transform, Duplex);
function TransformState(options, stream) {
    this.afterTransform = function (er, data) {
        return afterTransform(stream, er, data);
    };
    this.needTransform = false;
    this.transforming = false;
    this.writecb = null;
    this.writechunk = null;
}
function afterTransform(stream, er, data) {
    var ts = stream._transformState;
    ts.transforming = false;
    var cb = ts.writecb;
    if (!cb)
        return stream.emit('error', new Error('no writecb in Transform class'));
    ts.writechunk = null;
    ts.writecb = null;
    if (data !== null && data !== undefined)
        stream.push(data);
    if (cb)
        cb(er);
    var rs = stream._readableState;
    rs.reading = false;
    if (rs.needReadable || rs.length < rs.highWaterMark) {
        stream._read(rs.highWaterMark);
    }
}
function Transform(options) {
    if (!(this instanceof Transform))
        return new Transform(options);
    Duplex.call(this, options);
    var ts = this._transformState = new TransformState(options, this);
    var stream = this;
    this._readableState.needReadable = true;
    this._readableState.sync = false;
    this.once('finish', function () {
        if ('function' === typeof this._flush)
            this._flush(function (er) {
                done(stream, er);
            });
        else
            done(stream);
    });
}
Transform.prototype.push = function (chunk, encoding) {
    this._transformState.needTransform = false;
    return Duplex.prototype.push.call(this, chunk, encoding);
};
Transform.prototype._transform = function (chunk, encoding, cb) {
    throw new Error('not implemented');
};
Transform.prototype._write = function (chunk, encoding, cb) {
    var ts = this._transformState;
    ts.writecb = cb;
    ts.writechunk = chunk;
    ts.writeencoding = encoding;
    if (!ts.transforming) {
        var rs = this._readableState;
        if (ts.needTransform || rs.needReadable || rs.length < rs.highWaterMark)
            this._read(rs.highWaterMark);
    }
};
Transform.prototype._read = function (n) {
    var ts = this._transformState;
    if (ts.writechunk && ts.writecb && !ts.transforming) {
        ts.transforming = true;
        this._transform(ts.writechunk, ts.writeencoding, ts.afterTransform);
    } else {
        ts.needTransform = true;
    }
};
function done(stream, er) {
    if (er)
        return stream.emit('error', er);
    var ws = stream._writableState;
    var rs = stream._readableState;
    var ts = stream._transformState;
    if (ws.length)
        throw new Error('calling transform done when ws.length != 0');
    if (ts.transforming)
        throw new Error('calling transform done when still transforming');
    return stream.push(null);
}
});
require.define('15', function(module, exports, __dirname, __filename, undefined){
module.exports = Duplex;
var util = require('12', module);
var shims = require('18', module);
var timers = require('19', module);
var Readable = require('13', module);
var Writable = require('14', module);
util.inherits(Duplex, Readable);
shims.forEach(shims.keys(Writable.prototype), function (method) {
    if (!Duplex.prototype[method])
        Duplex.prototype[method] = Writable.prototype[method];
});
function Duplex(options) {
    if (!(this instanceof Duplex))
        return new Duplex(options);
    Readable.call(this, options);
    Writable.call(this, options);
    if (options && options.readable === false)
        this.readable = false;
    if (options && options.writable === false)
        this.writable = false;
    this.allowHalfOpen = true;
    if (options && options.allowHalfOpen === false)
        this.allowHalfOpen = false;
    this.once('end', onend);
}
function onend() {
    if (this.allowHalfOpen || this._writableState.ended)
        return;
    timers.setImmediate(shims.bind(this.end, this));
}
});
require.define('14', function(module, exports, __dirname, __filename, undefined){
module.exports = Writable;
Writable.WritableState = WritableState;
var util = require('12', module);
var Stream = require('8', module);
var timers = require('19', module);
var Buffer = require('20', module).Buffer;
util.inherits(Writable, Stream);
function WriteReq(chunk, encoding, cb) {
    this.chunk = chunk;
    this.encoding = encoding;
    this.callback = cb;
}
function WritableState(options, stream) {
    options = options || {};
    var hwm = options.highWaterMark;
    this.highWaterMark = hwm || hwm === 0 ? hwm : 16 * 1024;
    this.objectMode = !!options.objectMode;
    this.highWaterMark = ~~this.highWaterMark;
    this.needDrain = false;
    this.ending = false;
    this.ended = false;
    this.finished = false;
    var noDecode = options.decodeStrings === false;
    this.decodeStrings = !noDecode;
    this.defaultEncoding = options.defaultEncoding || 'utf8';
    this.length = 0;
    this.writing = false;
    this.sync = true;
    this.bufferProcessing = false;
    this.onwrite = function (er) {
        onwrite(stream, er);
    };
    this.writecb = null;
    this.writelen = 0;
    this.buffer = [];
}
function Writable(options) {
    if (!(this instanceof Writable) && !(this instanceof Stream.Duplex))
        return new Writable(options);
    this._writableState = new WritableState(options, this);
    this.writable = true;
    Stream.call(this);
}
Writable.prototype.pipe = function () {
    this.emit('error', new Error('Cannot pipe. Not readable.'));
};
function writeAfterEnd(stream, state, cb) {
    var er = new Error('write after end');
    stream.emit('error', er);
    timers.setImmediate(function () {
        cb(er);
    });
}
function validChunk(stream, state, chunk, cb) {
    var valid = true;
    if (!Buffer.isBuffer(chunk) && 'string' !== typeof chunk && chunk !== null && chunk !== undefined && !state.objectMode) {
        var er = new TypeError('Invalid non-string/buffer chunk');
        stream.emit('error', er);
        timers.setImmediate(function () {
            cb(er);
        });
        valid = false;
    }
    return valid;
}
Writable.prototype.write = function (chunk, encoding, cb) {
    var state = this._writableState;
    var ret = false;
    if (typeof encoding === 'function') {
        cb = encoding;
        encoding = null;
    }
    if (Buffer.isBuffer(chunk))
        encoding = 'buffer';
    else if (!encoding)
        encoding = state.defaultEncoding;
    if (typeof cb !== 'function')
        cb = function () {
        };
    if (state.ended)
        writeAfterEnd(this, state, cb);
    else if (validChunk(this, state, chunk, cb))
        ret = writeOrBuffer(this, state, chunk, encoding, cb);
    return ret;
};
function decodeChunk(state, chunk, encoding) {
    if (!state.objectMode && state.decodeStrings !== false && typeof chunk === 'string') {
        chunk = new Buffer(chunk, encoding);
    }
    return chunk;
}
function writeOrBuffer(stream, state, chunk, encoding, cb) {
    chunk = decodeChunk(state, chunk, encoding);
    var len = state.objectMode ? 1 : chunk.length;
    state.length += len;
    var ret = state.length < state.highWaterMark;
    state.needDrain = !ret;
    if (state.writing)
        state.buffer.push(new WriteReq(chunk, encoding, cb));
    else
        doWrite(stream, state, len, chunk, encoding, cb);
    return ret;
}
function doWrite(stream, state, len, chunk, encoding, cb) {
    state.writelen = len;
    state.writecb = cb;
    state.writing = true;
    state.sync = true;
    stream._write(chunk, encoding, state.onwrite);
    state.sync = false;
}
function onwriteError(stream, state, sync, er, cb) {
    if (sync)
        timers.setImmediate(function () {
            cb(er);
        });
    else
        cb(er);
    stream.emit('error', er);
}
function onwriteStateUpdate(state) {
    state.writing = false;
    state.writecb = null;
    state.length -= state.writelen;
    state.writelen = 0;
}
function onwrite(stream, er) {
    var state = stream._writableState;
    var sync = state.sync;
    var cb = state.writecb;
    onwriteStateUpdate(state);
    if (er)
        onwriteError(stream, state, sync, er, cb);
    else {
        var finished = needFinish(stream, state);
        if (!finished && !state.bufferProcessing && state.buffer.length)
            clearBuffer(stream, state);
        if (sync) {
            timers.setImmediate(function () {
                afterWrite(stream, state, finished, cb);
            });
        } else {
            afterWrite(stream, state, finished, cb);
        }
    }
}
function afterWrite(stream, state, finished, cb) {
    if (!finished)
        onwriteDrain(stream, state);
    cb();
    if (finished)
        finishMaybe(stream, state);
}
function onwriteDrain(stream, state) {
    if (state.length === 0 && state.needDrain) {
        state.needDrain = false;
        stream.emit('drain');
    }
}
function clearBuffer(stream, state) {
    state.bufferProcessing = true;
    for (var c = 0; c < state.buffer.length; c++) {
        var entry = state.buffer[c];
        var chunk = entry.chunk;
        var encoding = entry.encoding;
        var cb = entry.callback;
        var len = state.objectMode ? 1 : chunk.length;
        doWrite(stream, state, len, chunk, encoding, cb);
        if (state.writing) {
            c++;
            break;
        }
    }
    state.bufferProcessing = false;
    if (c < state.buffer.length)
        state.buffer = state.buffer.slice(c);
    else
        state.buffer.length = 0;
}
Writable.prototype._write = function (chunk, encoding, cb) {
    cb(new Error('not implemented'));
};
Writable.prototype.end = function (chunk, encoding, cb) {
    var state = this._writableState;
    if (typeof chunk === 'function') {
        cb = chunk;
        chunk = null;
        encoding = null;
    } else if (typeof encoding === 'function') {
        cb = encoding;
        encoding = null;
    }
    if (typeof chunk !== 'undefined' && chunk !== null)
        this.write(chunk, encoding);
    if (!state.ending && !state.finished)
        endWritable(this, state, cb);
};
function needFinish(stream, state) {
    return state.ending && state.length === 0 && !state.finished && !state.writing;
}
function finishMaybe(stream, state) {
    var need = needFinish(stream, state);
    if (need) {
        state.finished = true;
        stream.emit('finish');
    }
    return need;
}
function endWritable(stream, state, cb) {
    state.ending = true;
    finishMaybe(stream, state);
    if (cb) {
        if (state.finished)
            timers.setImmediate(cb);
        else
            stream.once('finish', cb);
    }
    state.ended = true;
}
});
require.define('20', function(module, exports, __dirname, __filename, undefined){
var assert;
exports.Buffer = Buffer;
exports.SlowBuffer = Buffer;
Buffer.poolSize = 8192;
exports.INSPECT_MAX_BYTES = 50;
function stringtrim(str) {
    if (str.trim)
        return str.trim();
    return str.replace(/^\s+|\s+$/g, '');
}
function Buffer(subject, encoding, offset) {
    if (!assert)
        assert = require('21', module);
    if (!(this instanceof Buffer)) {
        return new Buffer(subject, encoding, offset);
    }
    this.parent = this;
    this.offset = 0;
    if (encoding == 'base64' && typeof subject == 'string') {
        subject = stringtrim(subject);
        while (subject.length % 4 != 0) {
            subject = subject + '=';
        }
    }
    var type;
    if (typeof offset === 'number') {
        this.length = coerce(encoding);
        for (var i = 0; i < this.length; i++) {
            this[i] = subject.get(i + offset);
        }
    } else {
        switch (type = typeof subject) {
        case 'number':
            this.length = coerce(subject);
            break;
        case 'string':
            this.length = Buffer.byteLength(subject, encoding);
            break;
        case 'object':
            this.length = coerce(subject.length);
            break;
        default:
            throw new Error('First argument needs to be a number, ' + 'array or string.');
        }
        if (isArrayIsh(subject)) {
            for (var i = 0; i < this.length; i++) {
                if (subject instanceof Buffer) {
                    this[i] = subject.readUInt8(i);
                } else {
                    this[i] = subject[i];
                }
            }
        } else if (type == 'string') {
            this.length = this.write(subject, 0, encoding);
        } else if (type === 'number') {
            for (var i = 0; i < this.length; i++) {
                this[i] = 0;
            }
        }
    }
}
Buffer.prototype.get = function get(i) {
    if (i < 0 || i >= this.length)
        throw new Error('oob');
    return this[i];
};
Buffer.prototype.set = function set(i, v) {
    if (i < 0 || i >= this.length)
        throw new Error('oob');
    return this[i] = v;
};
Buffer.byteLength = function (str, encoding) {
    switch (encoding || 'utf8') {
    case 'hex':
        return str.length / 2;
    case 'utf8':
    case 'utf-8':
        return utf8ToBytes(str).length;
    case 'ascii':
    case 'binary':
        return str.length;
    case 'base64':
        return base64ToBytes(str).length;
    default:
        throw new Error('Unknown encoding');
    }
};
Buffer.prototype.utf8Write = function (string, offset, length) {
    var bytes, pos;
    return Buffer._charsWritten = blitBuffer(utf8ToBytes(string), this, offset, length);
};
Buffer.prototype.asciiWrite = function (string, offset, length) {
    var bytes, pos;
    return Buffer._charsWritten = blitBuffer(asciiToBytes(string), this, offset, length);
};
Buffer.prototype.binaryWrite = Buffer.prototype.asciiWrite;
Buffer.prototype.base64Write = function (string, offset, length) {
    var bytes, pos;
    return Buffer._charsWritten = blitBuffer(base64ToBytes(string), this, offset, length);
};
Buffer.prototype.base64Slice = function (start, end) {
    var bytes = Array.prototype.slice.apply(this, arguments);
    return require('22', module).fromByteArray(bytes);
};
Buffer.prototype.utf8Slice = function () {
    var bytes = Array.prototype.slice.apply(this, arguments);
    var res = '';
    var tmp = '';
    var i = 0;
    while (i < bytes.length) {
        if (bytes[i] <= 127) {
            res += decodeUtf8Char(tmp) + String.fromCharCode(bytes[i]);
            tmp = '';
        } else
            tmp += '%' + bytes[i].toString(16);
        i++;
    }
    return res + decodeUtf8Char(tmp);
};
Buffer.prototype.asciiSlice = function () {
    var bytes = Array.prototype.slice.apply(this, arguments);
    var ret = '';
    for (var i = 0; i < bytes.length; i++)
        ret += String.fromCharCode(bytes[i]);
    return ret;
};
Buffer.prototype.binarySlice = Buffer.prototype.asciiSlice;
Buffer.prototype.inspect = function () {
    var out = [], len = this.length;
    for (var i = 0; i < len; i++) {
        out[i] = toHex(this[i]);
        if (i == exports.INSPECT_MAX_BYTES) {
            out[i + 1] = '...';
            break;
        }
    }
    return '<Buffer ' + out.join(' ') + '>';
};
Buffer.prototype.hexSlice = function (start, end) {
    var len = this.length;
    if (!start || start < 0)
        start = 0;
    if (!end || end < 0 || end > len)
        end = len;
    var out = '';
    for (var i = start; i < end; i++) {
        out += toHex(this[i]);
    }
    return out;
};
Buffer.prototype.toString = function (encoding, start, end) {
    encoding = String(encoding || 'utf8').toLowerCase();
    start = +start || 0;
    if (typeof end == 'undefined')
        end = this.length;
    if (+end == start) {
        return '';
    }
    switch (encoding) {
    case 'hex':
        return this.hexSlice(start, end);
    case 'utf8':
    case 'utf-8':
        return this.utf8Slice(start, end);
    case 'ascii':
        return this.asciiSlice(start, end);
    case 'binary':
        return this.binarySlice(start, end);
    case 'base64':
        return this.base64Slice(start, end);
    case 'ucs2':
    case 'ucs-2':
        return this.ucs2Slice(start, end);
    default:
        throw new Error('Unknown encoding');
    }
};
Buffer.prototype.hexWrite = function (string, offset, length) {
    offset = +offset || 0;
    var remaining = this.length - offset;
    if (!length) {
        length = remaining;
    } else {
        length = +length;
        if (length > remaining) {
            length = remaining;
        }
    }
    var strLen = string.length;
    if (strLen % 2) {
        throw new Error('Invalid hex string');
    }
    if (length > strLen / 2) {
        length = strLen / 2;
    }
    for (var i = 0; i < length; i++) {
        var byte = parseInt(string.substr(i * 2, 2), 16);
        if (isNaN(byte))
            throw new Error('Invalid hex string');
        this[offset + i] = byte;
    }
    Buffer._charsWritten = i * 2;
    return i;
};
Buffer.prototype.write = function (string, offset, length, encoding) {
    if (isFinite(offset)) {
        if (!isFinite(length)) {
            encoding = length;
            length = undefined;
        }
    } else {
        var swap = encoding;
        encoding = offset;
        offset = length;
        length = swap;
    }
    offset = +offset || 0;
    var remaining = this.length - offset;
    if (!length) {
        length = remaining;
    } else {
        length = +length;
        if (length > remaining) {
            length = remaining;
        }
    }
    encoding = String(encoding || 'utf8').toLowerCase();
    switch (encoding) {
    case 'hex':
        return this.hexWrite(string, offset, length);
    case 'utf8':
    case 'utf-8':
        return this.utf8Write(string, offset, length);
    case 'ascii':
        return this.asciiWrite(string, offset, length);
    case 'binary':
        return this.binaryWrite(string, offset, length);
    case 'base64':
        return this.base64Write(string, offset, length);
    case 'ucs2':
    case 'ucs-2':
        return this.ucs2Write(string, offset, length);
    default:
        throw new Error('Unknown encoding');
    }
};
function clamp(index, len, defaultValue) {
    if (typeof index !== 'number')
        return defaultValue;
    index = ~~index;
    if (index >= len)
        return len;
    if (index >= 0)
        return index;
    index += len;
    if (index >= 0)
        return index;
    return 0;
}
Buffer.prototype.slice = function (start, end) {
    var len = this.length;
    start = clamp(start, len, 0);
    end = clamp(end, len, len);
    return new Buffer(this, end - start, +start);
};
Buffer.prototype.copy = function (target, target_start, start, end) {
    var source = this;
    start || (start = 0);
    if (end === undefined || isNaN(end)) {
        end = this.length;
    }
    target_start || (target_start = 0);
    if (end < start)
        throw new Error('sourceEnd < sourceStart');
    if (end === start)
        return 0;
    if (target.length == 0 || source.length == 0)
        return 0;
    if (target_start < 0 || target_start >= target.length) {
        throw new Error('targetStart out of bounds');
    }
    if (start < 0 || start >= source.length) {
        throw new Error('sourceStart out of bounds');
    }
    if (end < 0 || end > source.length) {
        throw new Error('sourceEnd out of bounds');
    }
    if (end > this.length) {
        end = this.length;
    }
    if (target.length - target_start < end - start) {
        end = target.length - target_start + start;
    }
    var temp = [];
    for (var i = start; i < end; i++) {
        assert.ok(typeof this[i] !== 'undefined', 'copying undefined buffer bytes!');
        temp.push(this[i]);
    }
    for (var i = target_start; i < target_start + temp.length; i++) {
        target[i] = temp[i - target_start];
    }
};
Buffer.prototype.fill = function fill(value, start, end) {
    value || (value = 0);
    start || (start = 0);
    end || (end = this.length);
    if (typeof value === 'string') {
        value = value.charCodeAt(0);
    }
    if (!(typeof value === 'number') || isNaN(value)) {
        throw new Error('value is not a number');
    }
    if (end < start)
        throw new Error('end < start');
    if (end === start)
        return 0;
    if (this.length == 0)
        return 0;
    if (start < 0 || start >= this.length) {
        throw new Error('start out of bounds');
    }
    if (end < 0 || end > this.length) {
        throw new Error('end out of bounds');
    }
    for (var i = start; i < end; i++) {
        this[i] = value;
    }
};
Buffer.isBuffer = function isBuffer(b) {
    return b instanceof Buffer || b instanceof Buffer;
};
Buffer.concat = function (list, totalLength) {
    if (!isArray(list)) {
        throw new Error('Usage: Buffer.concat(list, [totalLength])\n       list should be an Array.');
    }
    if (list.length === 0) {
        return new Buffer(0);
    } else if (list.length === 1) {
        return list[0];
    }
    if (typeof totalLength !== 'number') {
        totalLength = 0;
        for (var i = 0; i < list.length; i++) {
            var buf = list[i];
            totalLength += buf.length;
        }
    }
    var buffer = new Buffer(totalLength);
    var pos = 0;
    for (var i = 0; i < list.length; i++) {
        var buf = list[i];
        buf.copy(buffer, pos);
        pos += buf.length;
    }
    return buffer;
};
Buffer.isEncoding = function (encoding) {
    switch ((encoding + '').toLowerCase()) {
    case 'hex':
    case 'utf8':
    case 'utf-8':
    case 'ascii':
    case 'binary':
    case 'base64':
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
    case 'raw':
        return true;
    default:
        return false;
    }
};
function coerce(length) {
    length = ~~Math.ceil(+length);
    return length < 0 ? 0 : length;
}
function isArray(subject) {
    return (Array.isArray || function (subject) {
        return {}.toString.apply(subject) == '[object Array]';
    })(subject);
}
function isArrayIsh(subject) {
    return isArray(subject) || Buffer.isBuffer(subject) || subject && typeof subject === 'object' && typeof subject.length === 'number';
}
function toHex(n) {
    if (n < 16)
        return '0' + n.toString(16);
    return n.toString(16);
}
function utf8ToBytes(str) {
    var byteArray = [];
    for (var i = 0; i < str.length; i++)
        if (str.charCodeAt(i) <= 127)
            byteArray.push(str.charCodeAt(i));
        else {
            var h = encodeURIComponent(str.charAt(i)).substr(1).split('%');
            for (var j = 0; j < h.length; j++)
                byteArray.push(parseInt(h[j], 16));
        }
    return byteArray;
}
function asciiToBytes(str) {
    var byteArray = [];
    for (var i = 0; i < str.length; i++)
        byteArray.push(str.charCodeAt(i) & 255);
    return byteArray;
}
function base64ToBytes(str) {
    return require('22', module).toByteArray(str);
}
function blitBuffer(src, dst, offset, length) {
    var pos, i = 0;
    while (i < length) {
        if (i + offset >= dst.length || i >= src.length)
            break;
        dst[i + offset] = src[i];
        i++;
    }
    return i;
}
function decodeUtf8Char(str) {
    try {
        return decodeURIComponent(str);
    } catch (err) {
        return String.fromCharCode(65533);
    }
}
Buffer.prototype.readUInt8 = function (offset, noAssert) {
    var buffer = this;
    if (!noAssert) {
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset < buffer.length, 'Trying to read beyond buffer length');
    }
    if (offset >= buffer.length)
        return;
    return buffer[offset];
};
function readUInt16(buffer, offset, isBigEndian, noAssert) {
    var val = 0;
    if (!noAssert) {
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 1 < buffer.length, 'Trying to read beyond buffer length');
    }
    if (offset >= buffer.length)
        return 0;
    if (isBigEndian) {
        val = buffer[offset] << 8;
        if (offset + 1 < buffer.length) {
            val |= buffer[offset + 1];
        }
    } else {
        val = buffer[offset];
        if (offset + 1 < buffer.length) {
            val |= buffer[offset + 1] << 8;
        }
    }
    return val;
}
Buffer.prototype.readUInt16LE = function (offset, noAssert) {
    return readUInt16(this, offset, false, noAssert);
};
Buffer.prototype.readUInt16BE = function (offset, noAssert) {
    return readUInt16(this, offset, true, noAssert);
};
function readUInt32(buffer, offset, isBigEndian, noAssert) {
    var val = 0;
    if (!noAssert) {
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 3 < buffer.length, 'Trying to read beyond buffer length');
    }
    if (offset >= buffer.length)
        return 0;
    if (isBigEndian) {
        if (offset + 1 < buffer.length)
            val = buffer[offset + 1] << 16;
        if (offset + 2 < buffer.length)
            val |= buffer[offset + 2] << 8;
        if (offset + 3 < buffer.length)
            val |= buffer[offset + 3];
        val = val + (buffer[offset] << 24 >>> 0);
    } else {
        if (offset + 2 < buffer.length)
            val = buffer[offset + 2] << 16;
        if (offset + 1 < buffer.length)
            val |= buffer[offset + 1] << 8;
        val |= buffer[offset];
        if (offset + 3 < buffer.length)
            val = val + (buffer[offset + 3] << 24 >>> 0);
    }
    return val;
}
Buffer.prototype.readUInt32LE = function (offset, noAssert) {
    return readUInt32(this, offset, false, noAssert);
};
Buffer.prototype.readUInt32BE = function (offset, noAssert) {
    return readUInt32(this, offset, true, noAssert);
};
Buffer.prototype.readInt8 = function (offset, noAssert) {
    var buffer = this;
    var neg;
    if (!noAssert) {
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset < buffer.length, 'Trying to read beyond buffer length');
    }
    if (offset >= buffer.length)
        return;
    neg = buffer[offset] & 128;
    if (!neg) {
        return buffer[offset];
    }
    return (255 - buffer[offset] + 1) * -1;
};
function readInt16(buffer, offset, isBigEndian, noAssert) {
    var neg, val;
    if (!noAssert) {
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 1 < buffer.length, 'Trying to read beyond buffer length');
    }
    val = readUInt16(buffer, offset, isBigEndian, noAssert);
    neg = val & 32768;
    if (!neg) {
        return val;
    }
    return (65535 - val + 1) * -1;
}
Buffer.prototype.readInt16LE = function (offset, noAssert) {
    return readInt16(this, offset, false, noAssert);
};
Buffer.prototype.readInt16BE = function (offset, noAssert) {
    return readInt16(this, offset, true, noAssert);
};
function readInt32(buffer, offset, isBigEndian, noAssert) {
    var neg, val;
    if (!noAssert) {
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 3 < buffer.length, 'Trying to read beyond buffer length');
    }
    val = readUInt32(buffer, offset, isBigEndian, noAssert);
    neg = val & 2147483648;
    if (!neg) {
        return val;
    }
    return (4294967295 - val + 1) * -1;
}
Buffer.prototype.readInt32LE = function (offset, noAssert) {
    return readInt32(this, offset, false, noAssert);
};
Buffer.prototype.readInt32BE = function (offset, noAssert) {
    return readInt32(this, offset, true, noAssert);
};
function readFloat(buffer, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset + 3 < buffer.length, 'Trying to read beyond buffer length');
    }
    return require('23', module).readIEEE754(buffer, offset, isBigEndian, 23, 4);
}
Buffer.prototype.readFloatLE = function (offset, noAssert) {
    return readFloat(this, offset, false, noAssert);
};
Buffer.prototype.readFloatBE = function (offset, noAssert) {
    return readFloat(this, offset, true, noAssert);
};
function readDouble(buffer, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset + 7 < buffer.length, 'Trying to read beyond buffer length');
    }
    return require('23', module).readIEEE754(buffer, offset, isBigEndian, 52, 8);
}
Buffer.prototype.readDoubleLE = function (offset, noAssert) {
    return readDouble(this, offset, false, noAssert);
};
Buffer.prototype.readDoubleBE = function (offset, noAssert) {
    return readDouble(this, offset, true, noAssert);
};
function verifuint(value, max) {
    assert.ok(typeof value == 'number', 'cannot write a non-number as a number');
    assert.ok(value >= 0, 'specified a negative value for writing an unsigned value');
    assert.ok(value <= max, 'value is larger than maximum value for type');
    assert.ok(Math.floor(value) === value, 'value has a fractional component');
}
Buffer.prototype.writeUInt8 = function (value, offset, noAssert) {
    var buffer = this;
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset < buffer.length, 'trying to write beyond buffer length');
        verifuint(value, 255);
    }
    if (offset < buffer.length) {
        buffer[offset] = value;
    }
};
function writeUInt16(buffer, value, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 1 < buffer.length, 'trying to write beyond buffer length');
        verifuint(value, 65535);
    }
    for (var i = 0; i < Math.min(buffer.length - offset, 2); i++) {
        buffer[offset + i] = (value & 255 << 8 * (isBigEndian ? 1 - i : i)) >>> (isBigEndian ? 1 - i : i) * 8;
    }
}
Buffer.prototype.writeUInt16LE = function (value, offset, noAssert) {
    writeUInt16(this, value, offset, false, noAssert);
};
Buffer.prototype.writeUInt16BE = function (value, offset, noAssert) {
    writeUInt16(this, value, offset, true, noAssert);
};
function writeUInt32(buffer, value, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 3 < buffer.length, 'trying to write beyond buffer length');
        verifuint(value, 4294967295);
    }
    for (var i = 0; i < Math.min(buffer.length - offset, 4); i++) {
        buffer[offset + i] = value >>> (isBigEndian ? 3 - i : i) * 8 & 255;
    }
}
Buffer.prototype.writeUInt32LE = function (value, offset, noAssert) {
    writeUInt32(this, value, offset, false, noAssert);
};
Buffer.prototype.writeUInt32BE = function (value, offset, noAssert) {
    writeUInt32(this, value, offset, true, noAssert);
};
function verifsint(value, max, min) {
    assert.ok(typeof value == 'number', 'cannot write a non-number as a number');
    assert.ok(value <= max, 'value larger than maximum allowed value');
    assert.ok(value >= min, 'value smaller than minimum allowed value');
    assert.ok(Math.floor(value) === value, 'value has a fractional component');
}
function verifIEEE754(value, max, min) {
    assert.ok(typeof value == 'number', 'cannot write a non-number as a number');
    assert.ok(value <= max, 'value larger than maximum allowed value');
    assert.ok(value >= min, 'value smaller than minimum allowed value');
}
Buffer.prototype.writeInt8 = function (value, offset, noAssert) {
    var buffer = this;
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset < buffer.length, 'Trying to write beyond buffer length');
        verifsint(value, 127, -128);
    }
    if (value >= 0) {
        buffer.writeUInt8(value, offset, noAssert);
    } else {
        buffer.writeUInt8(255 + value + 1, offset, noAssert);
    }
};
function writeInt16(buffer, value, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 1 < buffer.length, 'Trying to write beyond buffer length');
        verifsint(value, 32767, -32768);
    }
    if (value >= 0) {
        writeUInt16(buffer, value, offset, isBigEndian, noAssert);
    } else {
        writeUInt16(buffer, 65535 + value + 1, offset, isBigEndian, noAssert);
    }
}
Buffer.prototype.writeInt16LE = function (value, offset, noAssert) {
    writeInt16(this, value, offset, false, noAssert);
};
Buffer.prototype.writeInt16BE = function (value, offset, noAssert) {
    writeInt16(this, value, offset, true, noAssert);
};
function writeInt32(buffer, value, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 3 < buffer.length, 'Trying to write beyond buffer length');
        verifsint(value, 2147483647, -2147483648);
    }
    if (value >= 0) {
        writeUInt32(buffer, value, offset, isBigEndian, noAssert);
    } else {
        writeUInt32(buffer, 4294967295 + value + 1, offset, isBigEndian, noAssert);
    }
}
Buffer.prototype.writeInt32LE = function (value, offset, noAssert) {
    writeInt32(this, value, offset, false, noAssert);
};
Buffer.prototype.writeInt32BE = function (value, offset, noAssert) {
    writeInt32(this, value, offset, true, noAssert);
};
function writeFloat(buffer, value, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 3 < buffer.length, 'Trying to write beyond buffer length');
        verifIEEE754(value, 3.4028234663852886e+38, -3.4028234663852886e+38);
    }
    require('23', module).writeIEEE754(buffer, value, offset, isBigEndian, 23, 4);
}
Buffer.prototype.writeFloatLE = function (value, offset, noAssert) {
    writeFloat(this, value, offset, false, noAssert);
};
Buffer.prototype.writeFloatBE = function (value, offset, noAssert) {
    writeFloat(this, value, offset, true, noAssert);
};
function writeDouble(buffer, value, offset, isBigEndian, noAssert) {
    if (!noAssert) {
        assert.ok(value !== undefined && value !== null, 'missing value');
        assert.ok(typeof isBigEndian === 'boolean', 'missing or invalid endian');
        assert.ok(offset !== undefined && offset !== null, 'missing offset');
        assert.ok(offset + 7 < buffer.length, 'Trying to write beyond buffer length');
        verifIEEE754(value, 1.7976931348623157e+308, -1.7976931348623157e+308);
    }
    require('23', module).writeIEEE754(buffer, value, offset, isBigEndian, 52, 8);
}
Buffer.prototype.writeDoubleLE = function (value, offset, noAssert) {
    writeDouble(this, value, offset, false, noAssert);
};
Buffer.prototype.writeDoubleBE = function (value, offset, noAssert) {
    writeDouble(this, value, offset, true, noAssert);
};
});
require.define('23', function(module, exports, __dirname, __filename, undefined){
exports.readIEEE754 = function (buffer, offset, isBE, mLen, nBytes) {
    var e, m, eLen = nBytes * 8 - mLen - 1, eMax = (1 << eLen) - 1, eBias = eMax >> 1, nBits = -7, i = isBE ? 0 : nBytes - 1, d = isBE ? 1 : -1, s = buffer[offset + i];
    i += d;
    e = s & (1 << -nBits) - 1;
    s >>= -nBits;
    nBits += eLen;
    for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8);
    m = e & (1 << -nBits) - 1;
    e >>= -nBits;
    nBits += mLen;
    for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8);
    if (e === 0) {
        e = 1 - eBias;
    } else if (e === eMax) {
        return m ? NaN : (s ? -1 : 1) * Infinity;
    } else {
        m = m + Math.pow(2, mLen);
        e = e - eBias;
    }
    return (s ? -1 : 1) * m * Math.pow(2, e - mLen);
};
exports.writeIEEE754 = function (buffer, value, offset, isBE, mLen, nBytes) {
    var e, m, c, eLen = nBytes * 8 - mLen - 1, eMax = (1 << eLen) - 1, eBias = eMax >> 1, rt = mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0, i = isBE ? nBytes - 1 : 0, d = isBE ? -1 : 1, s = value < 0 || value === 0 && 1 / value < 0 ? 1 : 0;
    value = Math.abs(value);
    if (isNaN(value) || value === Infinity) {
        m = isNaN(value) ? 1 : 0;
        e = eMax;
    } else {
        e = Math.floor(Math.log(value) / Math.LN2);
        if (value * (c = Math.pow(2, -e)) < 1) {
            e--;
            c *= 2;
        }
        if (e + eBias >= 1) {
            value += rt / c;
        } else {
            value += rt * Math.pow(2, 1 - eBias);
        }
        if (value * c >= 2) {
            e++;
            c /= 2;
        }
        if (e + eBias >= eMax) {
            m = 0;
            e = eMax;
        } else if (e + eBias >= 1) {
            m = (value * c - 1) * Math.pow(2, mLen);
            e = e + eBias;
        } else {
            m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen);
            e = 0;
        }
    }
    for (; mLen >= 8; buffer[offset + i] = m & 255, i += d, m /= 256, mLen -= 8);
    e = e << mLen | m;
    eLen += mLen;
    for (; eLen > 0; buffer[offset + i] = e & 255, i += d, e /= 256, eLen -= 8);
    buffer[offset + i - d] |= s * 128;
};
});
require.define('22', function(module, exports, __dirname, __filename, undefined){
(function (exports) {
    'use strict';
    var lookup = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
    function b64ToByteArray(b64) {
        var i, j, l, tmp, placeHolders, arr;
        if (b64.length % 4 > 0) {
            throw 'Invalid string. Length must be a multiple of 4';
        }
        placeHolders = b64.indexOf('=');
        placeHolders = placeHolders > 0 ? b64.length - placeHolders : 0;
        arr = [];
        l = placeHolders > 0 ? b64.length - 4 : b64.length;
        for (i = 0, j = 0; i < l; i += 4, j += 3) {
            tmp = lookup.indexOf(b64[i]) << 18 | lookup.indexOf(b64[i + 1]) << 12 | lookup.indexOf(b64[i + 2]) << 6 | lookup.indexOf(b64[i + 3]);
            arr.push((tmp & 16711680) >> 16);
            arr.push((tmp & 65280) >> 8);
            arr.push(tmp & 255);
        }
        if (placeHolders === 2) {
            tmp = lookup.indexOf(b64[i]) << 2 | lookup.indexOf(b64[i + 1]) >> 4;
            arr.push(tmp & 255);
        } else if (placeHolders === 1) {
            tmp = lookup.indexOf(b64[i]) << 10 | lookup.indexOf(b64[i + 1]) << 4 | lookup.indexOf(b64[i + 2]) >> 2;
            arr.push(tmp >> 8 & 255);
            arr.push(tmp & 255);
        }
        return arr;
    }
    function uint8ToBase64(uint8) {
        var i, extraBytes = uint8.length % 3, output = '', temp, length;
        function tripletToBase64(num) {
            return lookup[num >> 18 & 63] + lookup[num >> 12 & 63] + lookup[num >> 6 & 63] + lookup[num & 63];
        }
        ;
        for (i = 0, length = uint8.length - extraBytes; i < length; i += 3) {
            temp = (uint8[i] << 16) + (uint8[i + 1] << 8) + uint8[i + 2];
            output += tripletToBase64(temp);
        }
        switch (extraBytes) {
        case 1:
            temp = uint8[uint8.length - 1];
            output += lookup[temp >> 2];
            output += lookup[temp << 4 & 63];
            output += '==';
            break;
        case 2:
            temp = (uint8[uint8.length - 2] << 8) + uint8[uint8.length - 1];
            output += lookup[temp >> 10];
            output += lookup[temp >> 4 & 63];
            output += lookup[temp << 2 & 63];
            output += '=';
            break;
        }
        return output;
    }
    module.exports.toByteArray = b64ToByteArray;
    module.exports.fromByteArray = uint8ToBase64;
}());
});
require.define('21', function(module, exports, __dirname, __filename, undefined){
var util = require('12', module);
var shims = require('18', module);
var pSlice = Array.prototype.slice;
var assert = module.exports = ok;
assert.AssertionError = function AssertionError(options) {
    this.name = 'AssertionError';
    this.actual = options.actual;
    this.expected = options.expected;
    this.operator = options.operator;
    this.message = options.message || getMessage(this);
};
util.inherits(assert.AssertionError, Error);
function replacer(key, value) {
    if (util.isUndefined(value)) {
        return '' + value;
    }
    if (util.isNumber(value) && (isNaN(value) || !isFinite(value))) {
        return value.toString();
    }
    if (util.isFunction(value) || util.isRegExp(value)) {
        return value.toString();
    }
    return value;
}
function truncate(s, n) {
    if (util.isString(s)) {
        return s.length < n ? s : s.slice(0, n);
    } else {
        return s;
    }
}
function getMessage(self) {
    return truncate(JSON.stringify(self.actual, replacer), 128) + ' ' + self.operator + ' ' + truncate(JSON.stringify(self.expected, replacer), 128);
}
function fail(actual, expected, message, operator, stackStartFunction) {
    throw new assert.AssertionError({
        message: message,
        actual: actual,
        expected: expected,
        operator: operator,
        stackStartFunction: stackStartFunction
    });
}
assert.fail = fail;
function ok(value, message) {
    if (!value)
        fail(value, true, message, '==', assert.ok);
}
assert.ok = ok;
assert.equal = function equal(actual, expected, message) {
    if (actual != expected)
        fail(actual, expected, message, '==', assert.equal);
};
assert.notEqual = function notEqual(actual, expected, message) {
    if (actual == expected) {
        fail(actual, expected, message, '!=', assert.notEqual);
    }
};
assert.deepEqual = function deepEqual(actual, expected, message) {
    if (!_deepEqual(actual, expected)) {
        fail(actual, expected, message, 'deepEqual', assert.deepEqual);
    }
};
function _deepEqual(actual, expected) {
    if (actual === expected) {
        return true;
    } else if (util.isBuffer(actual) && util.isBuffer(expected)) {
        if (actual.length != expected.length)
            return false;
        for (var i = 0; i < actual.length; i++) {
            if (actual[i] !== expected[i])
                return false;
        }
        return true;
    } else if (util.isDate(actual) && util.isDate(expected)) {
        return actual.getTime() === expected.getTime();
    } else if (util.isRegExp(actual) && util.isRegExp(expected)) {
        return actual.source === expected.source && actual.global === expected.global && actual.multiline === expected.multiline && actual.lastIndex === expected.lastIndex && actual.ignoreCase === expected.ignoreCase;
    } else if (!util.isObject(actual) && !util.isObject(expected)) {
        return actual == expected;
    } else {
        return objEquiv(actual, expected);
    }
}
function isArguments(object) {
    return Object.prototype.toString.call(object) == '[object Arguments]';
}
function objEquiv(a, b) {
    if (util.isNullOrUndefined(a) || util.isNullOrUndefined(b))
        return false;
    if (a.prototype !== b.prototype)
        return false;
    if (isArguments(a)) {
        if (!isArguments(b)) {
            return false;
        }
        a = pSlice.call(a);
        b = pSlice.call(b);
        return _deepEqual(a, b);
    }
    try {
        var ka = shims.keys(a), kb = shims.keys(b), key, i;
    } catch (e) {
        return false;
    }
    if (ka.length != kb.length)
        return false;
    ka.sort();
    kb.sort();
    for (i = ka.length - 1; i >= 0; i--) {
        if (ka[i] != kb[i])
            return false;
    }
    for (i = ka.length - 1; i >= 0; i--) {
        key = ka[i];
        if (!_deepEqual(a[key], b[key]))
            return false;
    }
    return true;
}
assert.notDeepEqual = function notDeepEqual(actual, expected, message) {
    if (_deepEqual(actual, expected)) {
        fail(actual, expected, message, 'notDeepEqual', assert.notDeepEqual);
    }
};
assert.strictEqual = function strictEqual(actual, expected, message) {
    if (actual !== expected) {
        fail(actual, expected, message, '===', assert.strictEqual);
    }
};
assert.notStrictEqual = function notStrictEqual(actual, expected, message) {
    if (actual === expected) {
        fail(actual, expected, message, '!==', assert.notStrictEqual);
    }
};
function expectedException(actual, expected) {
    if (!actual || !expected) {
        return false;
    }
    if (Object.prototype.toString.call(expected) == '[object RegExp]') {
        return expected.test(actual);
    } else if (actual instanceof expected) {
        return true;
    } else if (expected.call({}, actual) === true) {
        return true;
    }
    return false;
}
function _throws(shouldThrow, block, expected, message) {
    var actual;
    if (util.isString(expected)) {
        message = expected;
        expected = null;
    }
    try {
        block();
    } catch (e) {
        actual = e;
    }
    message = (expected && expected.name ? ' (' + expected.name + ').' : '.') + (message ? ' ' + message : '.');
    if (shouldThrow && !actual) {
        fail(actual, expected, 'Missing expected exception' + message);
    }
    if (!shouldThrow && expectedException(actual, expected)) {
        fail(actual, expected, 'Got unwanted exception' + message);
    }
    if (shouldThrow && actual && expected && !expectedException(actual, expected) || !shouldThrow && actual) {
        throw actual;
    }
}
assert.throws = function (block, error, message) {
    _throws.apply(this, [true].concat(pSlice.call(arguments)));
};
assert.doesNotThrow = function (block, message) {
    _throws.apply(this, [false].concat(pSlice.call(arguments)));
};
assert.ifError = function (err) {
    if (err) {
        throw err;
    }
};
});
require.define('19', function(module, exports, __dirname, __filename, undefined){
try {
    if (!setTimeout.call) {
        var slicer = Array.prototype.slice;
        exports.setTimeout = function (fn) {
            var args = slicer.call(arguments, 1);
            return setTimeout(function () {
                return fn.apply(this, args);
            });
        };
        exports.setInterval = function (fn) {
            var args = slicer.call(arguments, 1);
            return setInterval(function () {
                return fn.apply(this, args);
            });
        };
    } else {
        exports.setTimeout = setTimeout;
        exports.setInterval = setInterval;
    }
    exports.clearTimeout = clearTimeout;
    exports.clearInterval = clearInterval;
    if (window.setImmediate) {
        exports.setImmediate = window.setImmediate;
        exports.clearImmediate = window.clearImmediate;
    }
    exports.setTimeout(function () {
    });
} catch (_) {
    function bind(f, context) {
        return function () {
            return f.apply(context, arguments);
        };
    }
    if (typeof window !== 'undefined') {
        exports.setTimeout = bind(setTimeout, window);
        exports.setInterval = bind(setInterval, window);
        exports.clearTimeout = bind(clearTimeout, window);
        exports.clearInterval = bind(clearInterval, window);
        if (window.setImmediate) {
            exports.setImmediate = bind(window.setImmediate, window);
            exports.clearImmediate = bind(window.clearImmediate, window);
        }
    } else {
        if (typeof setTimeout !== 'undefined') {
            exports.setTimeout = setTimeout;
        }
        if (typeof setInterval !== 'undefined') {
            exports.setInterval = setInterval;
        }
        if (typeof clearTimeout !== 'undefined') {
            exports.clearTimeout = clearTimeout;
        }
        if (typeof clearInterval === 'function') {
            exports.clearInterval = clearInterval;
        }
    }
}
exports.unref = function unref() {
};
exports.ref = function ref() {
};
if (!exports.setImmediate) {
    var currentKey = 0, queue = {}, active = false;
    exports.setImmediate = function () {
        function drain() {
            active = false;
            for (var key in queue) {
                if (queue.hasOwnProperty(currentKey, key)) {
                    var fn = queue[key];
                    delete queue[key];
                    fn();
                }
            }
        }
        if (typeof window !== 'undefined' && window.postMessage && window.addEventListener) {
            window.addEventListener('message', function (ev) {
                if (ev.source === window && ev.data === 'browserify-tick') {
                    ev.stopPropagation();
                    drain();
                }
            }, true);
            return function setImmediate(fn) {
                var id = ++currentKey;
                queue[id] = fn;
                if (!active) {
                    active = true;
                    window.postMessage('browserify-tick', '*');
                }
                return id;
            };
        } else {
            return function setImmediate(fn) {
                var id = ++currentKey;
                queue[id] = fn;
                if (!active) {
                    active = true;
                    setTimeout(drain, 0);
                }
                return id;
            };
        }
    }();
    exports.clearImmediate = function clearImmediate(id) {
        delete queue[id];
    };
}
});
require.define('13', function(module, exports, __dirname, __filename, undefined){
module.exports = Readable;
Readable.ReadableState = ReadableState;
var EE = require('11', module).EventEmitter;
var Stream = require('8', module);
var shims = require('18', module);
var Buffer = require('20', module).Buffer;
var timers = require('19', module);
var util = require('12', module);
var StringDecoder;
util.inherits(Readable, Stream);
function ReadableState(options, stream) {
    options = options || {};
    var hwm = options.highWaterMark;
    this.highWaterMark = hwm || hwm === 0 ? hwm : 16 * 1024;
    this.highWaterMark = ~~this.highWaterMark;
    this.buffer = [];
    this.length = 0;
    this.pipes = null;
    this.pipesCount = 0;
    this.flowing = false;
    this.ended = false;
    this.endEmitted = false;
    this.reading = false;
    this.calledRead = false;
    this.sync = true;
    this.needReadable = false;
    this.emittedReadable = false;
    this.readableListening = false;
    this.objectMode = !!options.objectMode;
    this.defaultEncoding = options.defaultEncoding || 'utf8';
    this.ranOut = false;
    this.awaitDrain = 0;
    this.readingMore = false;
    this.decoder = null;
    this.encoding = null;
    if (options.encoding) {
        if (!StringDecoder)
            StringDecoder = require('24', module).StringDecoder;
        this.decoder = new StringDecoder(options.encoding);
        this.encoding = options.encoding;
    }
}
function Readable(options) {
    if (!(this instanceof Readable))
        return new Readable(options);
    this._readableState = new ReadableState(options, this);
    this.readable = true;
    Stream.call(this);
}
Readable.prototype.push = function (chunk, encoding) {
    var state = this._readableState;
    if (typeof chunk === 'string' && !state.objectMode) {
        encoding = encoding || state.defaultEncoding;
        if (encoding !== state.encoding) {
            chunk = new Buffer(chunk, encoding);
            encoding = '';
        }
    }
    return readableAddChunk(this, state, chunk, encoding, false);
};
Readable.prototype.unshift = function (chunk) {
    var state = this._readableState;
    return readableAddChunk(this, state, chunk, '', true);
};
function readableAddChunk(stream, state, chunk, encoding, addToFront) {
    var er = chunkInvalid(state, chunk);
    if (er) {
        stream.emit('error', er);
    } else if (chunk === null || chunk === undefined) {
        state.reading = false;
        if (!state.ended)
            onEofChunk(stream, state);
    } else if (state.objectMode || chunk && chunk.length > 0) {
        if (state.ended && !addToFront) {
            var e = new Error('stream.push() after EOF');
            stream.emit('error', e);
        } else if (state.endEmitted && addToFront) {
            var e = new Error('stream.unshift() after end event');
            stream.emit('error', e);
        } else {
            if (state.decoder && !addToFront && !encoding)
                chunk = state.decoder.write(chunk);
            state.length += state.objectMode ? 1 : chunk.length;
            if (addToFront) {
                state.buffer.unshift(chunk);
            } else {
                state.reading = false;
                state.buffer.push(chunk);
            }
            if (state.needReadable)
                emitReadable(stream);
            maybeReadMore(stream, state);
        }
    } else if (!addToFront) {
        state.reading = false;
    }
    return needMoreData(state);
}
function needMoreData(state) {
    return !state.ended && (state.needReadable || state.length < state.highWaterMark || state.length === 0);
}
Readable.prototype.setEncoding = function (enc) {
    if (!StringDecoder)
        StringDecoder = require('24', module).StringDecoder;
    this._readableState.decoder = new StringDecoder(enc);
    this._readableState.encoding = enc;
};
var MAX_HWM = 8388608;
function roundUpToNextPowerOf2(n) {
    if (n >= MAX_HWM) {
        n = MAX_HWM;
    } else {
        n--;
        for (var p = 1; p < 32; p <<= 1)
            n |= n >> p;
        n++;
    }
    return n;
}
function howMuchToRead(n, state) {
    if (state.length === 0 && state.ended)
        return 0;
    if (state.objectMode)
        return n === 0 ? 0 : 1;
    if (isNaN(n) || n === null) {
        if (state.flowing && state.buffer.length)
            return state.buffer[0].length;
        else
            return state.length;
    }
    if (n <= 0)
        return 0;
    if (n > state.highWaterMark)
        state.highWaterMark = roundUpToNextPowerOf2(n);
    if (n > state.length) {
        if (!state.ended) {
            state.needReadable = true;
            return 0;
        } else
            return state.length;
    }
    return n;
}
Readable.prototype.read = function (n) {
    var state = this._readableState;
    state.calledRead = true;
    var nOrig = n;
    if (typeof n !== 'number' || n > 0)
        state.emittedReadable = false;
    if (n === 0 && state.needReadable && (state.length >= state.highWaterMark || state.ended)) {
        emitReadable(this);
        return null;
    }
    n = howMuchToRead(n, state);
    if (n === 0 && state.ended) {
        if (state.length === 0)
            endReadable(this);
        return null;
    }
    var doRead = state.needReadable;
    if (state.length - n <= state.highWaterMark)
        doRead = true;
    if (state.ended || state.reading)
        doRead = false;
    if (doRead) {
        state.reading = true;
        state.sync = true;
        if (state.length === 0)
            state.needReadable = true;
        this._read(state.highWaterMark);
        state.sync = false;
    }
    if (doRead && !state.reading)
        n = howMuchToRead(nOrig, state);
    var ret;
    if (n > 0)
        ret = fromList(n, state);
    else
        ret = null;
    if (ret === null) {
        state.needReadable = true;
        n = 0;
    }
    state.length -= n;
    if (state.length === 0 && !state.ended)
        state.needReadable = true;
    if (state.ended && !state.endEmitted && state.length === 0)
        endReadable(this);
    return ret;
};
function chunkInvalid(state, chunk) {
    var er = null;
    if (!Buffer.isBuffer(chunk) && 'string' !== typeof chunk && chunk !== null && chunk !== undefined && !state.objectMode && !er) {
        er = new TypeError('Invalid non-string/buffer chunk');
    }
    return er;
}
function onEofChunk(stream, state) {
    if (state.decoder && !state.ended) {
        var chunk = state.decoder.end();
        if (chunk && chunk.length) {
            state.buffer.push(chunk);
            state.length += state.objectMode ? 1 : chunk.length;
        }
    }
    state.ended = true;
    if (state.length > 0)
        emitReadable(stream);
    else
        endReadable(stream);
}
function emitReadable(stream) {
    var state = stream._readableState;
    state.needReadable = false;
    if (state.emittedReadable)
        return;
    state.emittedReadable = true;
    if (state.sync)
        timers.setImmediate(function () {
            emitReadable_(stream);
        });
    else
        emitReadable_(stream);
}
function emitReadable_(stream) {
    stream.emit('readable');
}
function maybeReadMore(stream, state) {
    if (!state.readingMore) {
        state.readingMore = true;
        timers.setImmediate(function () {
            maybeReadMore_(stream, state);
        });
    }
}
function maybeReadMore_(stream, state) {
    var len = state.length;
    while (!state.reading && !state.flowing && !state.ended && state.length < state.highWaterMark) {
        stream.read(0);
        if (len === state.length)
            break;
        else
            len = state.length;
    }
    state.readingMore = false;
}
Readable.prototype._read = function (n) {
    this.emit('error', new Error('not implemented'));
};
Readable.prototype.pipe = function (dest, pipeOpts) {
    var src = this;
    var state = this._readableState;
    switch (state.pipesCount) {
    case 0:
        state.pipes = dest;
        break;
    case 1:
        state.pipes = [
            state.pipes,
            dest
        ];
        break;
    default:
        state.pipes.push(dest);
        break;
    }
    state.pipesCount += 1;
    var doEnd = (!pipeOpts || pipeOpts.end !== false) && dest !== process.stdout && dest !== process.stderr;
    var endFn = doEnd ? onend : cleanup;
    if (state.endEmitted)
        timers.setImmediate(endFn);
    else
        src.once('end', endFn);
    dest.on('unpipe', onunpipe);
    function onunpipe(readable) {
        if (readable !== src)
            return;
        cleanup();
    }
    function onend() {
        dest.end();
    }
    var ondrain = pipeOnDrain(src);
    dest.on('drain', ondrain);
    function cleanup() {
        dest.removeListener('close', onclose);
        dest.removeListener('finish', onfinish);
        dest.removeListener('drain', ondrain);
        dest.removeListener('error', onerror);
        dest.removeListener('unpipe', onunpipe);
        src.removeListener('end', onend);
        src.removeListener('end', cleanup);
        if (!dest._writableState || dest._writableState.needDrain)
            ondrain();
    }
    var errListeners = EE.listenerCount(dest, 'error');
    function onerror(er) {
        unpipe();
        if (errListeners === 0 && EE.listenerCount(dest, 'error') === 0)
            dest.emit('error', er);
    }
    dest.once('error', onerror);
    function onclose() {
        dest.removeListener('finish', onfinish);
        unpipe();
    }
    dest.once('close', onclose);
    function onfinish() {
        dest.removeListener('close', onclose);
        unpipe();
    }
    dest.once('finish', onfinish);
    function unpipe() {
        src.unpipe(dest);
    }
    dest.emit('pipe', src);
    if (!state.flowing) {
        this.on('readable', pipeOnReadable);
        state.flowing = true;
        timers.setImmediate(function () {
            flow(src);
        });
    }
    return dest;
};
function pipeOnDrain(src) {
    return function () {
        var dest = this;
        var state = src._readableState;
        state.awaitDrain--;
        if (state.awaitDrain === 0)
            flow(src);
    };
}
function flow(src) {
    var state = src._readableState;
    var chunk;
    state.awaitDrain = 0;
    function write(dest, i, list) {
        var written = dest.write(chunk);
        if (false === written) {
            state.awaitDrain++;
        }
    }
    while (state.pipesCount && null !== (chunk = src.read())) {
        if (state.pipesCount === 1)
            write(state.pipes, 0, null);
        else
            shims.forEach(state.pipes, write);
        src.emit('data', chunk);
        if (state.awaitDrain > 0)
            return;
    }
    if (state.pipesCount === 0) {
        state.flowing = false;
        if (EE.listenerCount(src, 'data') > 0)
            emitDataEvents(src);
        return;
    }
    state.ranOut = true;
}
function pipeOnReadable() {
    if (this._readableState.ranOut) {
        this._readableState.ranOut = false;
        flow(this);
    }
}
Readable.prototype.unpipe = function (dest) {
    var state = this._readableState;
    if (state.pipesCount === 0)
        return this;
    if (state.pipesCount === 1) {
        if (dest && dest !== state.pipes)
            return this;
        if (!dest)
            dest = state.pipes;
        state.pipes = null;
        state.pipesCount = 0;
        this.removeListener('readable', pipeOnReadable);
        state.flowing = false;
        if (dest)
            dest.emit('unpipe', this);
        return this;
    }
    if (!dest) {
        var dests = state.pipes;
        var len = state.pipesCount;
        state.pipes = null;
        state.pipesCount = 0;
        this.removeListener('readable', pipeOnReadable);
        state.flowing = false;
        for (var i = 0; i < len; i++)
            dests[i].emit('unpipe', this);
        return this;
    }
    var i = shims.indexOf(state.pipes, dest);
    if (i === -1)
        return this;
    state.pipes.splice(i, 1);
    state.pipesCount -= 1;
    if (state.pipesCount === 1)
        state.pipes = state.pipes[0];
    dest.emit('unpipe', this);
    return this;
};
Readable.prototype.on = function (ev, fn) {
    var res = Stream.prototype.on.call(this, ev, fn);
    if (ev === 'data' && !this._readableState.flowing)
        emitDataEvents(this);
    if (ev === 'readable' && this.readable) {
        var state = this._readableState;
        if (!state.readableListening) {
            state.readableListening = true;
            state.emittedReadable = false;
            state.needReadable = true;
            if (!state.reading) {
                this.read(0);
            } else if (state.length) {
                emitReadable(this, state);
            }
        }
    }
    return res;
};
Readable.prototype.addListener = Readable.prototype.on;
Readable.prototype.resume = function () {
    emitDataEvents(this);
    this.read(0);
    this.emit('resume');
};
Readable.prototype.pause = function () {
    emitDataEvents(this, true);
    this.emit('pause');
};
function emitDataEvents(stream, startPaused) {
    var state = stream._readableState;
    if (state.flowing) {
        throw new Error('Cannot switch to old mode now.');
    }
    var paused = startPaused || false;
    var readable = false;
    stream.readable = true;
    stream.pipe = Stream.prototype.pipe;
    stream.on = stream.addListener = Stream.prototype.on;
    stream.on('readable', function () {
        readable = true;
        var c;
        while (!paused && null !== (c = stream.read()))
            stream.emit('data', c);
        if (c === null) {
            readable = false;
            stream._readableState.needReadable = true;
        }
    });
    stream.pause = function () {
        paused = true;
        this.emit('pause');
    };
    stream.resume = function () {
        paused = false;
        if (readable)
            timers.setImmediate(function () {
                stream.emit('readable');
            });
        else
            this.read(0);
        this.emit('resume');
    };
    stream.emit('readable');
}
Readable.prototype.wrap = function (stream) {
    var state = this._readableState;
    var paused = false;
    var self = this;
    stream.on('end', function () {
        if (state.decoder && !state.ended) {
            var chunk = state.decoder.end();
            if (chunk && chunk.length)
                self.push(chunk);
        }
        self.push(null);
    });
    stream.on('data', function (chunk) {
        if (state.decoder)
            chunk = state.decoder.write(chunk);
        if (!chunk || !state.objectMode && !chunk.length)
            return;
        var ret = self.push(chunk);
        if (!ret) {
            paused = true;
            stream.pause();
        }
    });
    for (var i in stream) {
        if (typeof stream[i] === 'function' && typeof this[i] === 'undefined') {
            this[i] = function (method) {
                return function () {
                    return stream[method].apply(stream, arguments);
                };
            }(i);
        }
    }
    var events = [
            'error',
            'close',
            'destroy',
            'pause',
            'resume'
        ];
    shims.forEach(events, function (ev) {
        stream.on(ev, shims.bind(self.emit, self, ev));
    });
    self._read = function (n) {
        if (paused) {
            paused = false;
            stream.resume();
        }
    };
    return self;
};
Readable._fromList = fromList;
function fromList(n, state) {
    var list = state.buffer;
    var length = state.length;
    var stringMode = !!state.decoder;
    var objectMode = !!state.objectMode;
    var ret;
    if (list.length === 0)
        return null;
    if (length === 0)
        ret = null;
    else if (objectMode)
        ret = list.shift();
    else if (!n || n >= length) {
        if (stringMode)
            ret = list.join('');
        else
            ret = Buffer.concat(list, length);
        list.length = 0;
    } else {
        if (n < list[0].length) {
            var buf = list[0];
            ret = buf.slice(0, n);
            list[0] = buf.slice(n);
        } else if (n === list[0].length) {
            ret = list.shift();
        } else {
            if (stringMode)
                ret = '';
            else
                ret = new Buffer(n);
            var c = 0;
            for (var i = 0, l = list.length; i < l && c < n; i++) {
                var buf = list[0];
                var cpy = Math.min(n - c, buf.length);
                if (stringMode)
                    ret += buf.slice(0, cpy);
                else
                    buf.copy(ret, c, 0, cpy);
                if (cpy < buf.length)
                    list[0] = buf.slice(cpy);
                else
                    list.shift();
                c += cpy;
            }
        }
    }
    return ret;
}
function endReadable(stream) {
    var state = stream._readableState;
    if (state.length > 0)
        throw new Error('endReadable called on non-empty stream');
    if (!state.endEmitted && state.calledRead) {
        state.ended = true;
        timers.setImmediate(function () {
            if (!state.endEmitted && state.length === 0) {
                state.endEmitted = true;
                stream.readable = false;
                stream.emit('end');
            }
        });
    }
}
});
require.define('24', function(module, exports, __dirname, __filename, undefined){
var Buffer = require('20', module).Buffer;
function assertEncoding(encoding) {
    if (encoding && !Buffer.isEncoding(encoding)) {
        throw new Error('Unknown encoding: ' + encoding);
    }
}
var StringDecoder = exports.StringDecoder = function (encoding) {
        this.encoding = (encoding || 'utf8').toLowerCase().replace(/[-_]/, '');
        assertEncoding(encoding);
        switch (this.encoding) {
        case 'utf8':
            this.surrogateSize = 3;
            break;
        case 'ucs2':
        case 'utf16le':
            this.surrogateSize = 2;
            this.detectIncompleteChar = utf16DetectIncompleteChar;
            break;
        case 'base64':
            this.surrogateSize = 3;
            this.detectIncompleteChar = base64DetectIncompleteChar;
            break;
        default:
            this.write = passThroughWrite;
            return;
        }
        this.charBuffer = new Buffer(6);
        this.charReceived = 0;
        this.charLength = 0;
    };
StringDecoder.prototype.write = function (buffer) {
    var charStr = '';
    var offset = 0;
    while (this.charLength) {
        var i = buffer.length >= this.charLength - this.charReceived ? this.charLength - this.charReceived : buffer.length;
        buffer.copy(this.charBuffer, this.charReceived, offset, i);
        this.charReceived += i - offset;
        offset = i;
        if (this.charReceived < this.charLength) {
            return '';
        }
        charStr = this.charBuffer.slice(0, this.charLength).toString(this.encoding);
        var charCode = charStr.charCodeAt(charStr.length - 1);
        if (charCode >= 55296 && charCode <= 56319) {
            this.charLength += this.surrogateSize;
            charStr = '';
            continue;
        }
        this.charReceived = this.charLength = 0;
        if (i == buffer.length)
            return charStr;
        buffer = buffer.slice(i, buffer.length);
        break;
    }
    var lenIncomplete = this.detectIncompleteChar(buffer);
    var end = buffer.length;
    if (this.charLength) {
        buffer.copy(this.charBuffer, 0, buffer.length - lenIncomplete, end);
        this.charReceived = lenIncomplete;
        end -= lenIncomplete;
    }
    charStr += buffer.toString(this.encoding, 0, end);
    var end = charStr.length - 1;
    var charCode = charStr.charCodeAt(end);
    if (charCode >= 55296 && charCode <= 56319) {
        var size = this.surrogateSize;
        this.charLength += size;
        this.charReceived += size;
        this.charBuffer.copy(this.charBuffer, size, 0, size);
        this.charBuffer.write(charStr.charAt(charStr.length - 1), this.encoding);
        return charStr.substring(0, end);
    }
    return charStr;
};
StringDecoder.prototype.detectIncompleteChar = function (buffer) {
    var i = buffer.length >= 3 ? 3 : buffer.length;
    for (; i > 0; i--) {
        var c = buffer[buffer.length - i];
        if (i == 1 && c >> 5 == 6) {
            this.charLength = 2;
            break;
        }
        if (i <= 2 && c >> 4 == 14) {
            this.charLength = 3;
            break;
        }
        if (i <= 3 && c >> 3 == 30) {
            this.charLength = 4;
            break;
        }
    }
    return i;
};
StringDecoder.prototype.end = function (buffer) {
    var res = '';
    if (buffer && buffer.length)
        res = this.write(buffer);
    if (this.charReceived) {
        var cr = this.charReceived;
        var buf = this.charBuffer;
        var enc = this.encoding;
        res += buf.slice(0, cr).toString(enc);
    }
    return res;
};
function passThroughWrite(buffer) {
    return buffer.toString(this.encoding);
}
function utf16DetectIncompleteChar(buffer) {
    var incomplete = this.charReceived = buffer.length % 2;
    this.charLength = incomplete ? 2 : 0;
    return incomplete;
}
function base64DetectIncompleteChar(buffer) {
    var incomplete = this.charReceived = buffer.length % 3;
    this.charLength = incomplete ? 3 : 0;
    return incomplete;
}
});
require.define('11', function(module, exports, __dirname, __filename, undefined){
var util = require('12', module);
function EventEmitter() {
    this._events = this._events || {};
    this._maxListeners = this._maxListeners || undefined;
}
module.exports = EventEmitter;
EventEmitter.EventEmitter = EventEmitter;
EventEmitter.prototype._events = undefined;
EventEmitter.prototype._maxListeners = undefined;
EventEmitter.defaultMaxListeners = 10;
EventEmitter.prototype.setMaxListeners = function (n) {
    if (!util.isNumber(n) || n < 0)
        throw TypeError('n must be a positive number');
    this._maxListeners = n;
    return this;
};
EventEmitter.prototype.emit = function (type) {
    var er, handler, len, args, i, listeners;
    if (!this._events)
        this._events = {};
    if (type === 'error') {
        if (!this._events.error || util.isObject(this._events.error) && !this._events.error.length) {
            er = arguments[1];
            if (er instanceof Error) {
                throw er;
            } else {
                throw TypeError('Uncaught, unspecified "error" event.');
            }
            return false;
        }
    }
    handler = this._events[type];
    if (util.isUndefined(handler))
        return false;
    if (util.isFunction(handler)) {
        switch (arguments.length) {
        case 1:
            handler.call(this);
            break;
        case 2:
            handler.call(this, arguments[1]);
            break;
        case 3:
            handler.call(this, arguments[1], arguments[2]);
            break;
        default:
            len = arguments.length;
            args = new Array(len - 1);
            for (i = 1; i < len; i++)
                args[i - 1] = arguments[i];
            handler.apply(this, args);
        }
    } else if (util.isObject(handler)) {
        len = arguments.length;
        args = new Array(len - 1);
        for (i = 1; i < len; i++)
            args[i - 1] = arguments[i];
        listeners = handler.slice();
        len = listeners.length;
        for (i = 0; i < len; i++)
            listeners[i].apply(this, args);
    }
    return true;
};
EventEmitter.prototype.addListener = function (type, listener) {
    var m;
    if (!util.isFunction(listener))
        throw TypeError('listener must be a function');
    if (!this._events)
        this._events = {};
    if (this._events.newListener)
        this.emit('newListener', type, util.isFunction(listener.listener) ? listener.listener : listener);
    if (!this._events[type])
        this._events[type] = listener;
    else if (util.isObject(this._events[type]))
        this._events[type].push(listener);
    else
        this._events[type] = [
            this._events[type],
            listener
        ];
    if (util.isObject(this._events[type]) && !this._events[type].warned) {
        var m;
        if (!util.isUndefined(this._maxListeners)) {
            m = this._maxListeners;
        } else {
            m = EventEmitter.defaultMaxListeners;
        }
        if (m && m > 0 && this._events[type].length > m) {
            this._events[type].warned = true;
            console.error('(node) warning: possible EventEmitter memory ' + 'leak detected. %d listeners added. ' + 'Use emitter.setMaxListeners() to increase limit.', this._events[type].length);
            console.trace();
        }
    }
    return this;
};
EventEmitter.prototype.on = EventEmitter.prototype.addListener;
EventEmitter.prototype.once = function (type, listener) {
    if (!util.isFunction(listener))
        throw TypeError('listener must be a function');
    function g() {
        this.removeListener(type, g);
        listener.apply(this, arguments);
    }
    g.listener = listener;
    this.on(type, g);
    return this;
};
EventEmitter.prototype.removeListener = function (type, listener) {
    var list, position, length, i;
    if (!util.isFunction(listener))
        throw TypeError('listener must be a function');
    if (!this._events || !this._events[type])
        return this;
    list = this._events[type];
    length = list.length;
    position = -1;
    if (list === listener || util.isFunction(list.listener) && list.listener === listener) {
        delete this._events[type];
        if (this._events.removeListener)
            this.emit('removeListener', type, listener);
    } else if (util.isObject(list)) {
        for (i = length; i-- > 0;) {
            if (list[i] === listener || list[i].listener && list[i].listener === listener) {
                position = i;
                break;
            }
        }
        if (position < 0)
            return this;
        if (list.length === 1) {
            list.length = 0;
            delete this._events[type];
        } else {
            list.splice(position, 1);
        }
        if (this._events.removeListener)
            this.emit('removeListener', type, listener);
    }
    return this;
};
EventEmitter.prototype.removeAllListeners = function (type) {
    var key, listeners;
    if (!this._events)
        return this;
    if (!this._events.removeListener) {
        if (arguments.length === 0)
            this._events = {};
        else if (this._events[type])
            delete this._events[type];
        return this;
    }
    if (arguments.length === 0) {
        for (key in this._events) {
            if (key === 'removeListener')
                continue;
            this.removeAllListeners(key);
        }
        this.removeAllListeners('removeListener');
        this._events = {};
        return this;
    }
    listeners = this._events[type];
    if (util.isFunction(listeners)) {
        this.removeListener(type, listeners);
    } else {
        while (listeners.length)
            this.removeListener(type, listeners[listeners.length - 1]);
    }
    delete this._events[type];
    return this;
};
EventEmitter.prototype.listeners = function (type) {
    var ret;
    if (!this._events || !this._events[type])
        ret = [];
    else if (util.isFunction(this._events[type]))
        ret = [this._events[type]];
    else
        ret = this._events[type].slice();
    return ret;
};
EventEmitter.listenerCount = function (emitter, type) {
    var ret;
    if (!emitter._events || !emitter._events[type])
        ret = 0;
    else if (util.isFunction(emitter._events[type]))
        ret = 1;
    else
        ret = emitter._events[type].length;
    return ret;
};
});
require.define('5', function(module, exports, __dirname, __filename, undefined){
var undef;
var toString = Object.prototype.toString;
function type(obj) {
    if (obj === undef)
        return 'undefined';
    if (obj === null)
        return 'null';
    var t = typeof obj;
    switch (t) {
    case 'boolean':
    case 'number':
    case 'string':
    case 'function':
        return t;
    }
    var str = toString.call(obj);
    switch (str) {
    case '[object Array]':
        return 'array';
    case '[object RegExp]':
        return 'regexp';
    case '[object Date]':
        return 'date';
    case '[object Arguments]':
        return 'arguments';
    case '[object Function]':
        return 'function';
    case '[object Boolean]':
        return 'boolean';
    case '[object Number]':
        return 'number';
    case '[object String]':
        return 'string';
    default:
        return 'object';
    }
}
exports.array = function (obj) {
    return type(obj) === 'array';
};
exports.regexp = function (obj) {
    return type(obj) === 'regexp';
};
exports.date = function (obj) {
    return type(obj) === 'date';
};
exports.arguments = function (obj) {
    return type(obj) === 'arguments';
};
exports.func = function (obj) {
    return type(obj) === 'function';
};
exports.boolean = function (obj) {
    return type(obj) === 'boolean';
};
exports.undefined = function (obj) {
    return obj === undef;
};
exports.number = function (obj) {
    return type(obj) === 'number';
};
exports.string = function (obj) {
    return type(obj) === 'string';
};
exports.nil = function (obj) {
    return obj === null || obj === undef;
};
exports.type = type;
});
require.define('2', function(module, exports, __dirname, __filename, undefined){
var is = require('5', module);
var main = require('25', module);
var range = require('26', module);
var array = require('27', module);
var string = require('28', module);
module.exports = function spipe(start, end, by) {
    switch (is.type(start)) {
    case 'number':
        return main(range(start, end, by));
    case 'array':
        return main(array(start));
    case 'string':
        return main(string(start));
    default:
        return main(start);
    }
};
});
require.define('28', function(module, exports, __dirname, __filename, undefined){
var AnythingStream = require('9', module);
var StringStream = AnythingStream.extend({
        constructor: function StringStream(string) {
            AnythingStream.call(this);
            this._string = string;
        },
        _read: function () {
            this.push(this._string);
            this._string = null;
            this.push(null);
        },
        _done: function () {
            return this._string === null;
        }
    });
module.exports = function string(str) {
    return new StringStream(str);
};
});
require.define('27', function(module, exports, __dirname, __filename, undefined){
var AnythingStream = require('9', module);
var ArrayStream = AnythingStream.extend({
        constructor: function ArrayStream(array) {
            AnythingStream.call(this);
            this._array = array;
            this._length = array.length;
            this._i = 0;
        },
        _read: function () {
            this.push(this._array[this._i++]);
        },
        _done: function () {
            return this._i >= this._length;
        }
    });
module.exports = function array(arr) {
    return new ArrayStream(arr);
};
});
require.define('26', function(module, exports, __dirname, __filename, undefined){
var is = require('5', module);
var AnythingStream = require('9', module);
var RangeStream = AnythingStream.extend({
        constructor: function RangeStream(start, stop, step) {
            AnythingStream.call(this, { objectMode: true });
            if (is.nil(stop)) {
                stop = start;
                start = 0;
            }
            this._current = start;
            this._stop = stop;
            this._step = step || 1;
        },
        _read: function () {
            var rv = this._current;
            this._update();
            this.push(rv);
        }
    });
var IncreasingRangeStream = RangeStream.extend({
        constructor: function IncreasingRangeStream(start, stop, step) {
            RangeStream.call(this, start, stop, step);
        },
        _done: function () {
            return this._current > this._stop;
        },
        _update: function () {
            this._current += this._step;
        }
    });
var DecreasingRangeStream = RangeStream.extend({
        constructor: function DecreasingRangeStream(start, stop, step) {
            RangeStream.call(this, start, stop, step);
        },
        _done: function () {
            return this._current < this._stop;
        },
        _update: function () {
            this._current -= this._step;
        }
    });
module.exports = function range(start, stop, step) {
    return is.nil(stop) || start < stop ? new IncreasingRangeStream(start, stop, step) : new DecreasingRangeStream(start, stop, step);
};
});
require.define('25', function(module, exports, __dirname, __filename, undefined){
var classic = require('6', module);
var is = require('5', module);
var PullStream = require('7', module);
var slice = Array.prototype.slice;
var Pipeline = PullStream.extend({
        constructor: function Pipeline(start, end) {
            PullStream.call(this, end);
            this._start = start;
        },
        _process: function (chunk) {
            this.push(chunk);
        },
        _write: function (chunk, encoding, callback) {
            return this._start._write(chunk, encoding, callback);
        }
    });
module.exports = function spipe(stream) {
    var start = stream;
    return function pipeline(fn) {
        if (arguments.length && typeof fn === 'function') {
            var args = slice.call(arguments, 1);
            stream = fn.apply(stream, args);
            return pipeline;
        }
        var eagerEvaluation = fn;
        if (is.nil(eagerEvaluation))
            eagerEvaluation = true;
        if (eagerEvaluation) {
            var buffer, tmpHandler, ended = false;
            stream.on('data', function (data) {
                buffer = buffer || [];
                buffer.push(data);
            });
            if (stream._done && stream._done())
                return buffer || [];
            stream.removeAllListeners('data');
            if (buffer) {
                while (buffer.length)
                    stream.unshift(buffer.shift());
            }
            stream._readableState.flowing = false;
        }
        return new Pipeline(start, stream);
    };
};
});
require.define('29', function(module, exports, __dirname, __filename, undefined){
var Readable = require('8', module).Readable;
var classic = require('6', module);
var _ = require('30', module);
var chunks = [
        'Some text ',
        'that is ',
        'split\n',
        'into ',
        'newlines. ',
        'This\nchunk\r\nhas\nmany\rlines\n'
    ];
var StubTextStream = classic({
        constructor: function StubTextStream() {
            Readable.call(this);
            this._chunks = chunks.slice();
        },
        _read: function () {
            var _this = this;
            setImmediate(function () {
                _this.push(_this._chunks.shift());
            });
        }
    }, Readable);
runMocha({
    'SplitStream': {
        'split text synchronously': function () {
            deepEqual(_(chunks).split().end(), [
                'Some text that is split',
                'into newlines. This',
                'chunk',
                'has',
                'many',
                'lines'
            ]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(new StubTextStream()).split().end();
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    'Some text that is split',
                    'into newlines. This',
                    'chunk',
                    'has',
                    'many',
                    'lines'
                ]);
                done();
            });
        }
    }
});
});
require.define('30', function(module, exports, __dirname, __filename, undefined){
var createChainable = require('31', module);
module.exports = createChainable({
    all: require('32', module),
    any: require('33', module),
    filter: require('34', module),
    find: require('35', module),
    groupBy: require('36', module),
    map: require('37', module),
    reduce: require('38', module),
    reject: require('39', module),
    split: require('40', module)
});
});
require.define('40', function(module, exports, __dirname, __filename, undefined){
var PullStream = require('7', module);
var SplitStream = PullStream.extend({
        constructor: function SplitStream(source, pattern) {
            PullStream.call(this, source);
            this._pattern = pattern || /\r\n|\r|\n/;
            this._buffered = '';
        },
        _process: function (chunk) {
            var match, line;
            this._buffered += chunk;
            while (match = this._pattern.exec(this._buffered)) {
                line = this._buffered.slice(0, match.index);
                this._buffered = this._buffered.slice(match.index + match[0].length);
                this.push(line);
            }
        }
    });
module.exports = function split(pattern) {
    return new SplitStream(this, pattern);
};
});
require.define('39', function(module, exports, __dirname, __filename, undefined){
var PullStream = require('7', module);
var RejectStream = PullStream.extend({
        constructor: function RejectStream(source, cb) {
            PullStream.call(this, source);
            this._cb = cb;
        },
        _process: function (chunk) {
            if (!this._cb(chunk)) {
                this._forward(chunk);
            }
        }
    });
module.exports = function reject(cb) {
    return new RejectStream(this, cb);
};
});
require.define('38', function(module, exports, __dirname, __filename, undefined){
var is = require('5', module);
var has = require('4', module);
var PullStream = require('7', module);
var ReduceStream = PullStream.extend({
        constructor: function ReduceStream(source, cb, initial) {
            PullStream.call(this, source);
            this._cb = cb;
            this._current = initial;
            this._started = !is.nil(initial);
        },
        _process: function (chunk) {
            if (this._started) {
                this._current = this._cb(this._current, chunk);
                if (this._done())
                    this._ended();
            } else {
                this._current = chunk;
                this._started = true;
            }
        },
        _ended: function () {
            if (has(this, '_current')) {
                var cur = this._current;
                delete this._current;
                if (is.func(this._preReduce))
                    cur = this._preReduce(cur);
                this._forward(cur);
            }
        }
    });
function reduce(cb, start) {
    return new ReduceStream(this, cb, start);
}
reduce.ReduceStream = ReduceStream;
module.exports = reduce;
});
require.define('37', function(module, exports, __dirname, __filename, undefined){
var PullStream = require('7', module);
var MapStream = PullStream.extend({
        constructor: function MapStream(source, cb) {
            PullStream.call(this, source);
            this._cb = cb;
        },
        _process: function (chunk) {
            this._forward(this._cb(chunk));
        }
    });
module.exports = function map(cb) {
    return new MapStream(this, cb);
};
});
require.define('36', function(module, exports, __dirname, __filename, undefined){
var has = require('4', module);
var ReduceStream = require('38', module).ReduceStream;
var keys = require('53', module);
var GroupByStream = ReduceStream.extend({
        constructor: function GroupByStream(source, cb) {
            ReduceStream.call(this, source, function (groups, item) {
                var key = cb(item);
                if (!has(groups, key))
                    groups[key] = [];
                groups[key].push(item);
                return groups;
            }, {});
        },
        _preReduce: function (reduced) {
            var k, ks = keys(reduced);
            while (ks.length > 1) {
                k = ks.shift();
                this._forward({
                    key: k,
                    elements: reduced[k]
                });
            }
            k = ks.shift();
            return {
                key: k,
                elements: reduced[k]
            };
        }
    });
module.exports = function groupBy(cb) {
    return new GroupByStream(this, cb);
};
});
require.define('35', function(module, exports, __dirname, __filename, undefined){
var PullStream = require('7', module);
var FindStream = PullStream.extend({
        constructor: function FindStream(source, cb) {
            PullStream.call(this, source);
            this._cb = cb;
        },
        _process: function (chunk) {
            if (this._cb(chunk)) {
                this.close();
                this._forward(chunk);
            }
        }
    });
module.exports = function find(cb) {
    return new FindStream(this, cb);
};
});
require.define('34', function(module, exports, __dirname, __filename, undefined){
var PullStream = require('7', module);
var FilterStream = PullStream.extend({
        constructor: function FilterStream(source, cb) {
            PullStream.call(this, source);
            this._cb = cb;
        },
        _process: function (chunk) {
            if (this._cb(chunk))
                this._forward(chunk);
        }
    });
module.exports = function filter(cb) {
    return new FilterStream(this, cb);
};
});
require.define('33', function(module, exports, __dirname, __filename, undefined){
var PullStream = require('7', module);
var AnyStream = PullStream.extend({
        constructor: function AnyStream(source, cb) {
            PullStream.call(this, source);
            this._cb = cb;
        },
        _process: function (chunk) {
            if (this._cb(chunk)) {
                this.close();
                this._forward(true);
                return;
            }
            if (this._done())
                this._forward(false);
        }
    });
module.exports = function any(cb) {
    return new AnyStream(this, cb);
};
});
require.define('32', function(module, exports, __dirname, __filename, undefined){
var PullStream = require('7', module);
var AllStream = PullStream.extend({
        constructor: function AllStream(source, cb) {
            PullStream.call(this, source);
            this._cb = cb;
        },
        _process: function (chunk) {
            if (!this._cb(chunk)) {
                this.close();
                this._forward(false);
                return;
            }
            if (this._done())
                this._forward(true);
        }
    });
module.exports = function all(cb) {
    return new AllStream(this, cb);
};
});
require.define('31', function(module, exports, __dirname, __filename, undefined){
var has = require('4', module);
var classic = require('6', module);
var spipe = require('2', module);
var slice = Array.prototype.slice;
module.exports = function createChainable(functionMap) {
    function Chainable() {
        var tgt = this;
        if (!(tgt instanceof Chainable))
            tgt = new Chainable();
        tgt._pipeline = spipe.apply(null, slice.call(arguments));
        return tgt;
    }
    for (var k in functionMap) {
        if (!has(functionMap, k))
            continue;
        Chainable.prototype[k] = function (name, fn) {
            return function () {
                this._pipeline.apply(null, [fn].concat(slice.call(arguments)));
                return this;
            };
        }(k, functionMap[k]);
    }
    Chainable.prototype.end = function (eager) {
        return this._pipeline(eager);
    };
    return Chainable;
};
});
require.define('41', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
function even(n) {
    return n % 2 === 0;
}
runMocha({
    'RejectStream': {
        'reject values synchronously': function () {
            deepEqual(_(1, 10).reject(even).end(), [
                1,
                3,
                5,
                7,
                9
            ]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(1, 10).reject(even).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    1,
                    3,
                    5,
                    7,
                    9
                ]);
                done();
            });
        }
    }
});
});
require.define('42', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
var Readable = require('8', module).Readable;
function toSum(result, n) {
    return result + n;
}
function toArray(result, n) {
    result.push(n);
    return result;
}
runMocha({
    'ReduceStream': {
        'reduce values synchronously': function () {
            deepEqual(_(1, 3).reduce(toSum).end(), [6]);
        },
        'reduce values with an initial value': function () {
            deepEqual(_(1, 3).reduce(toSum, 100).end(), [106]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(1, 10, 3).reduce(toSum).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [22]);
                done();
            });
        },
        'reduce incomplete streams': function (done) {
            var source = new Readable({ objectMode: true });
            source._read = function () {
            };
            source.push(1);
            setImmediate(function () {
                source.push(2);
                setImmediate(function () {
                    source.push(3);
                    source.push(null);
                });
            });
            _(source).reduce(toArray, []).end().on('data', function (array) {
                deepEqual([
                    1,
                    2,
                    3
                ], array);
                done();
            });
        }
    }
});
});
require.define('43', function(module, exports, __dirname, __filename, undefined){
var spipe = require('2', module);
runMocha({
    'RangeStream': {
        'returning synchronously': function () {
            equal(spipe(1, 1000)().length, 1000);
        },
        'increasing range': function () {
            deepEqual(spipe(1, 10)(), [
                1,
                2,
                3,
                4,
                5,
                6,
                7,
                8,
                9,
                10
            ]);
        },
        'increasing range with step': function () {
            deepEqual(spipe(1, 10, 3)(), [
                1,
                4,
                7,
                10
            ]);
        },
        'decreasing range': function () {
            deepEqual(spipe(10, 1)(), [
                10,
                9,
                8,
                7,
                6,
                5,
                4,
                3,
                2,
                1
            ]);
        },
        'decreasing range with step': function () {
            deepEqual(spipe(10, 1, 2)(), [
                10,
                8,
                6,
                4,
                2
            ]);
        },
        'never go past the end': function () {
            deepEqual(spipe(1, 10, 6)(), [
                1,
                7
            ]);
            deepEqual(spipe(10, 1, 6)(), [
                10,
                4
            ]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = spipe(1, 10, 4)(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    1,
                    5,
                    9
                ]);
                done();
            });
        },
        'only specify first argument to create ranges from 0': function () {
            deepEqual(spipe(5)(), [
                0,
                1,
                2,
                3,
                4,
                5
            ]);
        }
    }
});
});
require.define('44', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
function toDouble(n) {
    return 2 * n;
}
function toPower(n) {
    return n * n;
}
runMocha({
    'Map': {
        'transform each object synchronously': function () {
            deepEqual(_(1, 10, 3).map(toDouble).end(), [
                2,
                8,
                14,
                20
            ]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(1, 10, 3).map(toPower).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    1,
                    16,
                    49,
                    100
                ]);
                done();
            });
        }
    }
});
});
require.define('45', function(module, exports, __dirname, __filename, undefined){
var assert = require('21', module);
for (var k in assert)
    global[k] = assert[k];
var spipe = require('2', module);
var filter = require('34', module);
var find = require('35', module);
var map = require('37', module);
var reduce = require('38', module);
runMocha({
    'Chain': {
        'array -> filter -> map -> reduce': function () {
            var result = spipe([
                    1,
                    2,
                    3,
                    4,
                    5
                ])(filter, function (n) {
                    return n > 3;
                })(map, function (n) {
                    return n * n;
                })(reduce, function (result, n) {
                    return result + n;
                })();
            deepEqual(result, [41]);
        },
        'range -> map -> find -> map': function () {
            var result = spipe(1, 1000000000)(map, function (n) {
                    return {
                        square: n * n,
                        number: n
                    };
                })(find, function (obj) {
                    return obj.square >= 81;
                })(map, function (n) {
                    return n.number;
                })();
            deepEqual(result, [9]);
        }
    }
});
});
require.define('46', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
function floor(n) {
    return Math.floor(n);
}
runMocha({
    'GroupByStream': {
        'group values synchronously': function () {
            deepEqual(_([
                4.2,
                6.1,
                6.4
            ]).groupBy(floor).end(), [
                {
                    key: 4,
                    elements: [4.2]
                },
                {
                    key: 6,
                    elements: [
                        6.1,
                        6.4
                    ]
                }
            ]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _([
                    4.2,
                    6.1,
                    6.4
                ]).groupBy(floor).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    {
                        key: 4,
                        elements: [4.2]
                    },
                    {
                        key: 6,
                        elements: [
                            6.1,
                            6.4
                        ]
                    }
                ]);
                done();
            });
        }
    }
});
});
require.define('47', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
function predicate(n) {
    return n % 30 === 0;
}
runMocha({
    'FindStream': {
        'find values synchronously': function () {
            deepEqual(_(1, 10000000000).find(predicate).end(), [30]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(1, 10000000000).find(predicate).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [30]);
                done();
            });
        }
    }
});
});
require.define('48', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
function even(n) {
    return n % 2 === 0;
}
runMocha({
    'FilterStream': {
        'filter values synchronously': function () {
            deepEqual(_(1, 10).filter(even).end(), [
                2,
                4,
                6,
                8,
                10
            ]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(1, 10).filter(even).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    2,
                    4,
                    6,
                    8,
                    10
                ]);
                done();
            });
        }
    }
});
});
require.define('49', function(module, exports, __dirname, __filename, undefined){
var spipe = require('2', module);
var array = require('27', module);
runMocha({
    'ArrayStream': {
        'array': function () {
            deepEqual(spipe([
                1,
                2,
                3
            ])(), [
                1,
                2,
                3
            ]);
        },
        'array-like objects': function () {
            var result = spipe(array({
                    '0': 2,
                    4: 5,
                    length: 5
                }))();
            equal(result[0], 2);
            equal(result[1], undefined);
            equal(result[2], undefined);
            equal(result[3], undefined);
            equal(result[4], 5);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = spipe([
                    1,
                    2,
                    3
                ])(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [
                    1,
                    2,
                    3
                ]);
                done();
            });
        }
    }
});
});
require.define('50', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
function isEven(n) {
    return n % 2 === 0;
}
runMocha({
    'AnyStream': {
        'test streams synchronously': function () {
            deepEqual(_(1, 1000, 2).any(isEven).end(), [false]);
        },
        'closes the pipeline as soon as it finds a matching chunk': function () {
            deepEqual(_(1, 10000000000).any(isEven).end(), [true]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(1, 10000000000).any(isEven).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [true]);
                done();
            });
        }
    }
});
});
require.define('51', function(module, exports, __dirname, __filename, undefined){
var _ = require('30', module);
function areEven(n) {
    return n % 2 === 0;
}
runMocha({
    'AllStream': {
        'test streams synchronously': function () {
            deepEqual(_(0, 1000, 2).all(areEven).end(), [true]);
        },
        'closes the source stream as soon as a chunk doesnt match': function () {
            deepEqual(_(1, 10000000000).all(areEven).end(), [false]);
        },
        'lazily evaluate the stream': function (done) {
            var result = [];
            var stream = _(1, 10000000000).all(areEven).end(false);
            stream.on('data', function (n) {
                result.push(n);
            });
            stream.on('end', function () {
                deepEqual(result, [false]);
                done();
            });
        }
    }
});
});
require.define('52', function(module, exports, __dirname, __filename, undefined){
var util = require('12', module);
var assert = require('21', module);
var slice = Array.prototype.slice;
var console;
var times = {};
if (typeof global !== 'undefined' && global.console) {
    console = global.console;
} else if (typeof window !== 'undefined' && window.console) {
    console = window.console;
} else {
    console = {};
}
var functions = [
        [
            log,
            'log'
        ],
        [
            info,
            'info'
        ],
        [
            warn,
            'warn'
        ],
        [
            error,
            'error'
        ],
        [
            time,
            'time'
        ],
        [
            timeEnd,
            'timeEnd'
        ],
        [
            trace,
            'trace'
        ],
        [
            dir,
            'dir'
        ],
        [
            assert,
            'assert'
        ]
    ];
for (var i = 0; i < functions.length; i++) {
    var tuple = functions[i];
    var f = tuple[0];
    var name = tuple[1];
    if (!console[name]) {
        console[name] = f;
    }
}
module.exports = console;
function log() {
}
function info() {
    console.log.apply(console, arguments);
}
function warn() {
    console.log.apply(console, arguments);
}
function error() {
    console.warn.apply(console, arguments);
}
function time(label) {
    times[label] = Date.now();
}
function timeEnd(label) {
    var time = times[label];
    if (!time) {
        throw new Error('No such label: ' + label);
    }
    var duration = Date.now() - time;
    console.log(label + ': ' + duration + 'ms');
}
function trace() {
    var err = new Error();
    err.name = 'Trace';
    err.message = util.format.apply(null, arguments);
    console.error(err.stack);
}
function dir(object) {
    console.log(util.inspect(object) + '\n');
}
function assert(expression) {
    if (!expression) {
        var arr = slice.call(arguments, 1);
        assert.ok(false, util.format.apply(null, arr));
    }
}
});
require.define('53', function(module, exports, __dirname, __filename, undefined){
module.exports = Object.keys || require('54', module);
});
require.define('54', function(module, exports, __dirname, __filename, undefined){
(function () {
    'use strict';
    var has = Object.prototype.hasOwnProperty, toString = Object.prototype.toString, forEach = require('55', module), isArgs = require('56', module), hasDontEnumBug = !{ 'toString': null }.propertyIsEnumerable('toString'), hasProtoEnumBug = function () {
        }.propertyIsEnumerable('prototype'), dontEnums = [
            'toString',
            'toLocaleString',
            'valueOf',
            'hasOwnProperty',
            'isPrototypeOf',
            'propertyIsEnumerable',
            'constructor'
        ], keysShim;
    keysShim = function keys(object) {
        var isObject = object !== null && typeof object === 'object', isFunction = toString.call(object) === '[object Function]', isArguments = isArgs(object), theKeys = [];
        if (!isObject && !isFunction && !isArguments) {
            throw new TypeError('Object.keys called on a non-object');
        }
        if (isArguments) {
            forEach(object, function (value) {
                theKeys.push(value);
            });
        } else {
            var name, skipProto = hasProtoEnumBug && isFunction;
            for (name in object) {
                if (!(skipProto && name === 'prototype') && has.call(object, name)) {
                    theKeys.push(name);
                }
            }
        }
        if (hasDontEnumBug) {
            var ctor = object.constructor, skipConstructor = ctor && ctor.prototype === object;
            forEach(dontEnums, function (dontEnum) {
                if (!(skipConstructor && dontEnum === 'constructor') && has.call(object, dontEnum)) {
                    theKeys.push(dontEnum);
                }
            });
        }
        return theKeys;
    };
    module.exports = keysShim;
}());
});
require.define('56', function(module, exports, __dirname, __filename, undefined){
var toString = Object.prototype.toString;
module.exports = function isArguments(value) {
    var str = toString.call(value);
    var isArguments = str === '[object Arguments]';
    if (!isArguments) {
        isArguments = str !== '[object Array]' && value !== null && typeof value === 'object' && typeof value.length === 'number' && value.length >= 0 && toString.call(value.callee) === '[object Function]';
    }
    return isArguments;
};
});
require.define('55', function(module, exports, __dirname, __filename, undefined){
var hasOwn = Object.prototype.hasOwnProperty;
var toString = Object.prototype.toString;
var isFunction = function (fn) {
    var isFunc = typeof fn === 'function' && !(fn instanceof RegExp) || toString.call(fn) === '[object Function]';
    if (!isFunc && typeof window !== 'undefined') {
        isFunc = fn === window.setTimeout || fn === window.alert || fn === window.confirm || fn === window.prompt;
    }
    return isFunc;
};
module.exports = function forEach(obj, fn) {
    if (!isFunction(fn)) {
        throw new TypeError('iterator must be a function');
    }
    var i, k, isString = typeof obj === 'string', l = obj.length, context = arguments.length > 2 ? arguments[2] : null;
    if (l === +l) {
        for (i = 0; i < l; i++) {
            if (context === null) {
                fn(isString ? obj.charAt(i) : obj[i], i, obj);
            } else {
                fn.call(context, isString ? obj.charAt(i) : obj[i], i, obj);
            }
        }
    } else {
        for (k in obj) {
            if (hasOwn.call(obj, k)) {
                if (context === null) {
                    fn(obj[k], k, obj);
                } else {
                    fn.call(context, obj[k], k, obj);
                }
            }
        }
    }
};
});
var Buffer = require('20').Buffer;
if (!Buffer.prototype.toJSON)
  Buffer.prototype.toJSON = function() {
    return Array.prototype.slice.call(this, 0);
  };
var console = require('52');
var setImmediate = require('19').setImmediate;
var process = (function() { var global = this;
  var cwd = '/';
  return {
    title: 'browser',
    version: 'v0.10.20',
    browser: true,
    env: {},
    on: function() {},
    argv: [],
    nextTick: setImmediate,
    cwd: function(){ return cwd; },
    chdir: function(dir){ cwd = dir; }
  };
})();
require('51');
require('50');
require('49');
require('48');
require('47');
require('46');
require('45');
require('44');
require('43');
require('42');
require('41');
require('29');
return require('1');
})((function() {
  var loading = {};
  var files = {};
  var outer;
  if (typeof require === 'function') {
    outer = require;
  }
  function inner(id, parentModule) {
    if({}.hasOwnProperty.call(inner.cache, id))
      return inner.cache[id];

    if({}.hasOwnProperty.call(loading, id))
      return loading[id].exports;

    var resolved = inner.resolve(id);
    if(!resolved && outer) {
      return inner.cache[id] = outer(id);
    }
    if(!resolved) throw new Error("Failed to resolve module '" + id + "'");

    var dirname;
    var filename = files[id] || '';
    if (filename && typeof __dirname === 'string')
      filename = __dirname + '/' + filename;
    if (filename)
      dirname = filename.slice(0, filename.lastIndexOf('/') + 1);
    else
      dirname = '';
    var module$ = {
      id: id,
      require: inner,
      exports: {},
      loaded: false,
      parent: parentModule,
      children: []
    };
    if(parentModule) parentModule.children.push(module$);

    loading[id] = module$;
    resolved.call(this, module$, module$.exports, dirname, filename);
    inner.cache[id] = module$.exports;
    delete loading[id];
    module$.loaded = true;
    return inner.cache[id] = module$.exports;
  }

  inner.modules = {};
  inner.cache = {};

  inner.resolve = function(id){
    return {}.hasOwnProperty.call(inner.modules, id) ? inner.modules[id] : void 0;
  };
  inner.define = function(id, fn){ inner.modules[id] = fn; };

  return inner;
})()));
//# sourceMappingURL=test.js.map